@@ -1,4 +1,5 @@
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
+ * Copyright by The HDF Group.                                               *
  * Copyright by the Board of Trustees of the University of Illinois.         *
  * All rights reserved.                                                      *
  *                                                                           *
@@ -8,8 +9,8 @@
  * of the source code distribution tree; Copyright.html can be found at the  *
  * root level of an installed copy of the electronic HDF5 document set and   *
  * is linked from the top-level documents page.  It can also be found at     *
- * http://hdf.ncsa.uiuc.edu/HDF5/doc/Copyright.html.  If you do not have     *
- * access to either file, you may request a copy from hdfhelp@ncsa.uiuc.edu. *
+ * http://hdfgroup.org/HDF5/doc/Copyright.html.  If you do not have          *
+ * access to either file, you may request a copy from help@hdfgroup.org.     *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
 #include <string>
@@ -62,10 +63,19 @@ H5T_class_t AbstractDs::getTypeClass() const
    // Gets the datatype used by this dataset or attribute.
    // p_get_type calls either H5Dget_type or H5Aget_type depending on
    // which object invokes getTypeClass
-   DataType datatype(p_get_type());
+   hid_t datatype_id;
+   try {
+      datatype_id = p_get_type();  // returned value is already validated
+   }
+   catch (DataSetIException E) {
+      throw DataTypeIException("DataSet::getTypeClass", E.getDetailMsg());
+   }
+   catch (AttributeIException E) {
+      throw DataTypeIException("Attribute::getTypeClass", E.getDetailMsg());
+   }
 
    // Gets the class of the datatype and validate it before returning
-   H5T_class_t type_class = H5Tget_class( datatype.getId());
+   H5T_class_t type_class = H5Tget_class(datatype_id);
    if( type_class != H5T_NO_CLASS )
       return( type_class );
    else
@@ -85,19 +95,25 @@ H5T_class_t AbstractDs::getTypeClass() const
 //--------------------------------------------------------------------------
 DataType AbstractDs::getDataType() const
 {
-   // Gets the id of the datatype used by this dataset or attribute.
-   // p_get_type calls either H5Dget_type or H5Aget_type depending on
-   // which object invokes getTypeClass
-   hid_t datatype_id = p_get_type();  // returned value is already validated
-
-   // Create and return the DataType object
-   DataType datatype( datatype_id );
-   return( datatype );
+   // Gets the id of the datatype used by this dataset or attribute using
+   // p_get_type.  p_get_type calls either H5Dget_type or H5Aget_type
+   // depending on which object invokes getDataType.  Then, create and
+   // return the DataType object
+   try {
+      DataType datatype(p_get_type());
+      return(datatype);
+   }
+   catch (DataSetIException E) {
+      throw DataTypeIException("DataSet::getDataType", E.getDetailMsg());
+   }
+   catch (AttributeIException E) {
+      throw DataTypeIException("Attribute::getDataType", E.getDetailMsg());
+   }
 }
 
 //--------------------------------------------------------------------------
 // Function:	AbstractDs::getArrayType
-///\brief	Returns the compound datatype of this abstract dataset which
+///\brief	Returns the array datatype of this abstract dataset which
 ///		can be a dataset or an attribute.
 ///\return	ArrayType instance
 ///\exception	H5::DataTypeIException
@@ -105,8 +121,20 @@ DataType AbstractDs::getDataType() const
 //--------------------------------------------------------------------------
 ArrayType AbstractDs::getArrayType() const
 {
-   ArrayType arraytype(p_get_type());
-   return(arraytype);
+   // Gets the id of the datatype used by this dataset or attribute using
+   // p_get_type.  p_get_type calls either H5Dget_type or H5Aget_type
+   // depending on which object invokes getArrayType.  Then, create and
+   // return the ArrayType object
+   try {
+      ArrayType arraytype(p_get_type());
+      return(arraytype);
+   }
+   catch (DataSetIException E) {
+      throw DataTypeIException("DataSet::getArrayType", E.getDetailMsg());
+   }
+   catch (AttributeIException E) {
+      throw DataTypeIException("Attribute::getArrayType", E.getDetailMsg());
+   }
 }
 
 //--------------------------------------------------------------------------
@@ -119,8 +147,20 @@ ArrayType AbstractDs::getArrayType() const
 //--------------------------------------------------------------------------
 CompType AbstractDs::getCompType() const
 {
-   CompType comptype(p_get_type());
-   return(comptype);
+   // Gets the id of the datatype used by this dataset or attribute using
+   // p_get_type.  p_get_type calls either H5Dget_type or H5Aget_type
+   // depending on which object invokes getCompType.  Then, create and
+   // return the CompType object
+   try {
+      CompType comptype(p_get_type());
+      return(comptype);
+   }
+   catch (DataSetIException E) {
+      throw DataTypeIException("DataSet::getCompType", E.getDetailMsg());
+   }
+   catch (AttributeIException E) {
+      throw DataTypeIException("Attribute::getCompType", E.getDetailMsg());
+   }
 }
 
 //--------------------------------------------------------------------------
@@ -133,22 +173,20 @@ CompType AbstractDs::getCompType() const
 //--------------------------------------------------------------------------
 EnumType AbstractDs::getEnumType() const
 {
-   EnumType enumtype(p_get_type());
-   return(enumtype);
-}
-
-//--------------------------------------------------------------------------
-// Function:	AbstractDs::getFloatType
-///\brief	Returns the floating-point datatype of this abstract dataset,
-///		which can be a dataset or an attribute.
-///\return	FloatType instance
-///\exception	H5::DataTypeIException
-// Programmer	Binh-Minh Ribler - 2000
-//--------------------------------------------------------------------------
-FloatType AbstractDs::getFloatType() const
-{
-   FloatType floatype(p_get_type());
-   return(floatype);
+   // Gets the id of the datatype used by this dataset or attribute using
+   // p_get_type.  p_get_type calls either H5Dget_type or H5Aget_type
+   // depending on which object invokes getEnumType.  Then, create and
+   // return the EnumType object
+   try {
+      EnumType enumtype(p_get_type());
+      return(enumtype);
+   }
+   catch (DataSetIException E) {
+      throw DataTypeIException("DataSet::getEnumType", E.getDetailMsg());
+   }
+   catch (AttributeIException E) {
+      throw DataTypeIException("Attribute::getEnumType", E.getDetailMsg());
+   }
 }
 
 //--------------------------------------------------------------------------
@@ -161,8 +199,46 @@ FloatType AbstractDs::getFloatType() const
 //--------------------------------------------------------------------------
 IntType AbstractDs::getIntType() const
 {
-   IntType inttype(p_get_type());
-   return(inttype);
+   // Gets the id of the datatype used by this dataset or attribute using
+   // p_get_type.  p_get_type calls either H5Dget_type or H5Aget_type
+   // depending on which object invokes getIntType.  Then, create and
+   // return the IntType object
+   try {
+      IntType inttype(p_get_type());
+      return(inttype);
+   }
+   catch (DataSetIException E) {
+      throw DataTypeIException("DataSet::getIntType", E.getDetailMsg());
+   }
+   catch (AttributeIException E) {
+      throw DataTypeIException("Attribute::getIntType", E.getDetailMsg());
+   }
+}
+
+//--------------------------------------------------------------------------
+// Function:	AbstractDs::getFloatType
+///\brief	Returns the floating-point datatype of this abstract dataset,
+///		which can be a dataset or an attribute.
+///\return	FloatType instance
+///\exception	H5::DataTypeIException
+// Programmer	Binh-Minh Ribler - 2000
+//--------------------------------------------------------------------------
+FloatType AbstractDs::getFloatType() const
+{
+   // Gets the id of the datatype used by this dataset or attribute using
+   // p_get_type.  p_get_type calls either H5Dget_type or H5Aget_type
+   // depending on which object invokes getFloatType.  Then, create and
+   // return the FloatType object
+   try {
+      FloatType floatype(p_get_type());
+      return(floatype);
+   }
+   catch (DataSetIException E) {
+      throw DataTypeIException("DataSet::getFloatType", E.getDetailMsg());
+   }
+   catch (AttributeIException E) {
+      throw DataTypeIException("Attribute::getFloatType", E.getDetailMsg());
+   }
 }
 
 //--------------------------------------------------------------------------
@@ -175,8 +251,20 @@ IntType AbstractDs::getIntType() const
 //--------------------------------------------------------------------------
 StrType AbstractDs::getStrType() const
 {
-   StrType strtype(p_get_type());
-   return(strtype);
+   // Gets the id of the datatype used by this dataset or attribute using
+   // p_get_type.  p_get_type calls either H5Dget_type or H5Aget_type
+   // depending on which object invokes getStrType.  Then, create and
+   // return the StrType object
+   try {
+      StrType strtype(p_get_type());
+      return(strtype);
+   }
+   catch (DataSetIException E) {
+      throw DataTypeIException("DataSet::getStrType", E.getDetailMsg());
+   }
+   catch (AttributeIException E) {
+      throw DataTypeIException("Attribute::getStrType", E.getDetailMsg());
+   }
 }
 
 //--------------------------------------------------------------------------
@@ -189,8 +277,20 @@ StrType AbstractDs::getStrType() const
 //--------------------------------------------------------------------------
 VarLenType AbstractDs::getVarLenType() const
 {
-   VarLenType varlentype(p_get_type());
-   return(varlentype);
+   // Gets the id of the datatype used by this dataset or attribute using
+   // p_get_type.  p_get_type calls either H5Dget_type or H5Aget_type
+   // depending on which object invokes getVarLenType.  Then, create and
+   // return the VarLenType object
+   try {
+      VarLenType varlentype(p_get_type());
+      return(varlentype);
+   }
+   catch (DataSetIException E) {
+      throw DataTypeIException("DataSet::getVarLenType", E.getDetailMsg());
+   }
+   catch (AttributeIException E) {
+      throw DataTypeIException("Attribute::getVarLenType", E.getDetailMsg());
+   }
 }
 
 //--------------------------------------------------------------------------
