@@ -1,4 +1,5 @@
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
+ * Copyright by The HDF Group.                                               *
  * Copyright by the Board of Trustees of the University of Illinois.         *
  * All rights reserved.                                                      *
  *                                                                           *
@@ -8,16 +9,16 @@
  * of the source code distribution tree; Copyright.html can be found at the  *
  * root level of an installed copy of the electronic HDF5 document set and   *
  * is linked from the top-level documents page.  It can also be found at     *
- * http://hdf.ncsa.uiuc.edu/HDF5/doc/Copyright.html.  If you do not have     *
- * access to either file, you may request a copy from hdfhelp@ncsa.uiuc.edu. *
+ * http://hdfgroup.org/HDF5/doc/Copyright.html.  If you do not have          *
+ * access to either file, you may request a copy from help@hdfgroup.org.     *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
-#include <string>
 #ifdef OLD_HEADER_FILENAME
 #include <iostream.h>
 #else
 #include <iostream>
 #endif
+#include <string>
 
 #include "H5Include.h"
 #include "H5Exception.h"
@@ -26,6 +27,10 @@
 
 #ifndef H5_NO_NAMESPACE
 namespace H5 {
+#ifndef H5_NO_STD
+    using std::cerr;
+    using std::endl;
+#endif  // H5_NO_STD
 #endif
 
 //--------------------------------------------------------------------------
@@ -42,7 +47,7 @@ const DataSpace DataSpace::ALL( H5S_ALL );
 ///\exception	H5::DataSpaceIException
 // Programmer	Binh-Minh Ribler - 2000
 //--------------------------------------------------------------------------
-DataSpace::DataSpace( H5S_class_t type ) : IdComponent()
+DataSpace::DataSpace( H5S_class_t type ) : IdComponent(0)
 {
    id = H5Screate( type );
    if( id < 0 )
@@ -60,7 +65,7 @@ DataSpace::DataSpace( H5S_class_t type ) : IdComponent()
 ///\exception	H5::DataSpaceIException
 // Programmer	Binh-Minh Ribler - 2000
 //--------------------------------------------------------------------------
-DataSpace::DataSpace( int rank, const hsize_t * dims, const hsize_t * maxdims) : IdComponent()
+DataSpace::DataSpace( int rank, const hsize_t * dims, const hsize_t * maxdims) : IdComponent(0)
 {
    id = H5Screate_simple( rank, dims, maxdims );
    if( id < 0 )
@@ -94,21 +99,22 @@ DataSpace::DataSpace( const DataSpace& original ) : IdComponent( original ) {}
 ///\exception	H5::DataSpaceIException
 // Programmer	Binh-Minh Ribler - 2000
 // Modification
-//		Replaced resetIdComponent with decRefCount to use C library
-//		ID reference counting mechanism - BMR, Feb 20, 2005
+//		- Replaced resetIdComponent() with decRefCount() to use C
+//		library ID reference counting mechanism - BMR, Feb 20, 2005
+//		- Replaced decRefCount with close() to let the C library
+//		handle the reference counting - BMR, Jun 1, 2006
 //--------------------------------------------------------------------------
 void DataSpace::copy( const DataSpace& like_space )
 {
-   // If this object has a valid id, appropriately decrement reference
-   // counter and close the id.
+   // If this object has an hdf5 valid id, close it
    if( id != H5S_ALL ) {
       try {
-         decRefCount();
+         close();
       }
       catch (Exception close_error) {
          throw DataSpaceIException("DataSpace::copy", close_error.getDetailMsg());
       }
-   }  // if
+   }  // end if
 
    // call C routine to copy the dataspace
    id = H5Scopy( like_space.getId() );
@@ -130,8 +136,9 @@ void DataSpace::copy( const DataSpace& like_space )
 //--------------------------------------------------------------------------
 DataSpace& DataSpace::operator=( const DataSpace& rhs )
 {
-   copy(rhs);
-   return(*this);
+    if (this != &rhs)
+	copy(rhs);
+    return(*this);
 }
 
 //--------------------------------------------------------------------------
@@ -394,7 +401,7 @@ hssize_t DataSpace::getSelectElemNpoints () const
 ///\par Description
 ///		For more information, please refer to the C layer Reference
 ///		Manual at:
-/// http://hdf.ncsa.uiuc.edu/HDF5/doc/RM_H5S.html#Dataspace-SelectElemPointList
+/// <A HREF="../RM_H5S.html#Dataspace-SelectElemPointList">../RM_H5S.html#Dataspace-SelectElemPointList</A>
 // Programmer	Binh-Minh Ribler - 2000
 //--------------------------------------------------------------------------
 void DataSpace::getSelectElemPointlist ( hsize_t startpoint, hsize_t numpoints, hsize_t *buf ) const
@@ -404,7 +411,7 @@ void DataSpace::getSelectElemPointlist ( hsize_t startpoint, hsize_t numpoints,
    if( ret_value < 0 )
    {
       throw DataSpaceIException("DataSpace::getSelectElemPointlist",
-                "H5Sget_select_elem_pointlist failed");
+		"H5Sget_select_elem_pointlist failed");
    }
 }
 
@@ -418,7 +425,7 @@ void DataSpace::getSelectElemPointlist ( hsize_t startpoint, hsize_t numpoints,
 ///\par Description
 ///		For more information, please refer to the C layer Reference
 ///		Manual at:
-/// http://hdf.ncsa.uiuc.edu/HDF5/doc/RM_H5S.html#Dataspace-SelectBounds
+/// <A HREF="../RM_H5S.html#Dataspace-SelectBounds">../RM_H5S.html#Dataspace-SelectBounds</A>
 // Programmer	Binh-Minh Ribler - 2000
 //--------------------------------------------------------------------------
 void DataSpace::getSelectBounds ( hsize_t* start, hsize_t* end ) const
@@ -427,7 +434,7 @@ void DataSpace::getSelectBounds ( hsize_t* start, hsize_t* end ) const
    if( ret_value < 0 )
    {
       throw DataSpaceIException("DataSpace::getSelectBounds",
-                "H5Sget_select_bounds failed");
+		"H5Sget_select_bounds failed");
    }
 }
 
@@ -444,7 +451,7 @@ void DataSpace::getSelectBounds ( hsize_t* start, hsize_t* end ) const
 ///\par Description
 ///		For more information, please refer to the C layer Reference
 ///		Manual at:
-/// http://hdf.ncsa.uiuc.edu/HDF5/doc/RM_H5S.html#Dataspace-SelectElements
+/// <A HREF="../RM_H5S.html#Dataspace-SelectElements">../RM_H5S.html#Dataspace-SelectElements</A>
 // Programmer	Binh-Minh Ribler - 2000
 //--------------------------------------------------------------------------
 void DataSpace::selectElements ( H5S_seloper_t op, const size_t num_elements, const hsize_t *coord[ ] ) const
@@ -454,7 +461,7 @@ void DataSpace::selectElements ( H5S_seloper_t op, const size_t num_elements, co
    if( ret_value < 0 )
    {
       throw DataSpaceIException("DataSpace::selectElements",
-                "H5Sselect_elements failed");
+		"H5Sselect_elements failed");
    }
 }
 
@@ -487,7 +494,7 @@ void DataSpace::selectNone () const
    if( ret_value < 0 )
    {
       throw DataSpaceIException("DataSpace::selectNone",
-                "H5Sselect_none failed");
+		"H5Sselect_none failed");
    }
 }
 
@@ -510,7 +517,7 @@ bool DataSpace::selectValid () const
    else
    {
       throw DataSpaceIException("DataSpace::selectValid",
-                "H5Sselect_valid returns negative value");
+		"H5Sselect_valid returns negative value");
    }
 }
 
@@ -526,7 +533,7 @@ bool DataSpace::selectValid () const
 ///\par Description
 ///		For more information, please refer to the C layer Reference
 ///		Manual at:
-/// http://hdf.ncsa.uiuc.edu/HDF5/doc/RM_H5S.html#Dataspace-SelectHyperslab
+/// <A HREF="../RM_H5S.html#Dataspace-SelectHyperslab">../RM_H5S.html#Dataspace-SelectHyperslab</A>
 // Programmer	Binh-Minh Ribler - 2000
 //--------------------------------------------------------------------------
 void DataSpace::selectHyperslab( H5S_seloper_t op, const hsize_t *count, const hsize_t *start, const hsize_t *stride, const hsize_t *block ) const
@@ -549,18 +556,17 @@ void DataSpace::selectHyperslab( H5S_seloper_t op, const hsize_t *count, const h
 //--------------------------------------------------------------------------
 void DataSpace::close()
 {
-   if( id != H5S_ALL ) // not a constant, should call H5Sclose
-   {
-      herr_t ret_value = H5Sclose(id);
-      if( ret_value < 0 )
-      {
-	 throw DataSpaceIException("DataSpace::close", "H5Sclose failed");
-      }
-      // reset the id because the dataspace that it represents is now closed
-      id = 0;
-   }
-   else // cannot close a constant
-      throw DataSpaceIException("DataSpace::close", "Cannot close a constant");
+    // check if id is a valid hdf5 object id before trying to close it
+    if (p_valid_id(id))
+    {
+	herr_t ret_value = H5Sclose(id);
+	if( ret_value < 0 )
+	{
+	    throw DataSpaceIException("DataSpace::close", "H5Sclose failed");
+	}
+	// reset the id because the dataspace that it represents is now closed
+	id = 0;
+    }
 }
 
 //--------------------------------------------------------------------------
@@ -568,21 +574,19 @@ void DataSpace::close()
 ///\brief	Properly terminates access to this dataspace.
 // Programmer	Binh-Minh Ribler - 2000
 // Modification
-//		Replaced resetIdComponent with decRefCount to use C library
-//		ID reference counting mechanism - BMR, Feb 20, 2005
+//		- Replaced resetIdComponent() with decRefCount() to use C
+//		library ID reference counting mechanism - BMR, Feb 20, 2005
+//		- Replaced decRefCount with close() to let the C library
+//		handle the reference counting - BMR, Jun 1, 2006
 //--------------------------------------------------------------------------
 DataSpace::~DataSpace()
 {
-   // If this object has a valid id, appropriately decrement reference
-   // counter and close the id.
-   if( id != H5S_ALL ) {
-      try {
-         decRefCount();
-      }
-      catch (Exception close_error) {
-	 cerr << "DataSpace::~DataSpace - " << close_error.getDetailMsg() << endl;
-      }
-   }  // if
+    try {
+	close();
+    }
+    catch (Exception close_error) {
+	cerr << "DataSpace::~DataSpace - " << close_error.getDetailMsg() << endl;
+    }
 }
 
 #ifndef H5_NO_NAMESPACE
