@@ -1,4 +1,5 @@
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
+ * Copyright by The HDF Group.                                               *
  * Copyright by the Board of Trustees of the University of Illinois.         *
  * All rights reserved.                                                      *
  *                                                                           *
@@ -8,8 +9,8 @@
  * of the source code distribution tree; Copyright.html can be found at the  *
  * root level of an installed copy of the electronic HDF5 document set and   *
  * is linked from the top-level documents page.  It can also be found at     *
- * http://hdf.ncsa.uiuc.edu/HDF5/doc/Copyright.html.  If you do not have     *
- * access to either file, you may request a copy from hdfhelp@ncsa.uiuc.edu. *
+ * http://hdfgroup.org/HDF5/doc/Copyright.html.  If you do not have          *
+ * access to either file, you may request a copy from help@hdfgroup.org.     *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
 #include <string>
@@ -31,7 +32,7 @@ const FileAccPropList FileAccPropList::DEFAULT;
 
 //--------------------------------------------------------------------------
 // Function:	Default Constructor
-///\brief	Default constructor: creates a file access property list
+///\brief	Creates a file access property list
 // Programmer:	Binh-Minh Ribler - 2000
 //--------------------------------------------------------------------------
 FileAccPropList::FileAccPropList() : PropList( H5P_FILE_ACCESS ) {}
@@ -39,7 +40,7 @@ FileAccPropList::FileAccPropList() : PropList( H5P_FILE_ACCESS ) {}
 //--------------------------------------------------------------------------
 // Function:	FileAccPropList copy constructor
 ///\brief	Copy Constructor: makes a copy of the original
-///             FileAccPropList object.
+///		FileAccPropList object.
 // Programmer:	Binh-Minh Ribler - 2000
 //--------------------------------------------------------------------------
 FileAccPropList::FileAccPropList(const FileAccPropList& orig) : PropList(orig) {}
@@ -47,7 +48,7 @@ FileAccPropList::FileAccPropList(const FileAccPropList& orig) : PropList(orig) {
 //--------------------------------------------------------------------------
 // Function:	FileAccPropList overloaded constructor
 ///\brief	Creates a file access property list using the id of an
-///             existing one.
+///		existing one.
 // Programmer:  Binh-Minh Ribler - 2000
 //--------------------------------------------------------------------------
 FileAccPropList::FileAccPropList(const hid_t plist_id) : PropList(plist_id) {}
@@ -75,7 +76,7 @@ void FileAccPropList::setStdio() const
 ///		driver was set for the property list.  The driver ID is
 ///		only valid as long as the file driver remains registered.
 ///		Valid driver identifiers can be found at:
-/// http://hdf.ncsa.uiuc.edu/HDF5/doc/RM_H5P.html#Property-GetDriver
+/// <A HREF="../RM_H5P.html#Property-GetDriver">../RM_H5P.html#Property-GetDriver</A>
 ///\exception	H5::PropListIException
 // Programmer:  Binh-Minh Ribler - April, 2004
 //--------------------------------------------------------------------------
@@ -98,7 +99,7 @@ hid_t FileAccPropList::getDriver() const
 ///\par Description
 ///		For a list of valid driver identifiers, please see the C
 ///		layer Reference Manual at:
-/// http://hdf.ncsa.uiuc.edu/HDF5/doc/RM_H5P.html#Property-GetDriver
+/// <A HREF="../RM_H5P.html#Property-GetDriver">../RM_H5P.html#Property-GetDriver</A>
 // Programmer:  Binh-Minh Ribler - April, 2004
 //--------------------------------------------------------------------------
 void FileAccPropList::setDriver(hid_t new_driver_id, const void *new_driver_info) const
@@ -156,7 +157,7 @@ hsize_t FileAccPropList::getFamilyOffset() const
 ///\par Description
 ///		For more details on the use of \c H5FD_CORE driver, please
 ///		refer to
-/// http://hdf.ncsa.uiuc.edu/HDF5/doc/RM_H5P.html#Property-SetFaplCore
+/// <A HREF="../RM_H5P.html#Property-SetFaplCore">../RM_H5P.html#Property-SetFaplCore</A>
 // Programmer:  Binh-Minh Ribler - April, 2004
 //--------------------------------------------------------------------------
 void FileAccPropList::setCore (size_t increment, hbool_t backing_store) const
@@ -230,8 +231,8 @@ void FileAccPropList::getFamily(hsize_t& memb_size, FileAccPropList& memb_plist)
 //--------------------------------------------------------------------------
 // Function:	FileAccPropList::getFamily
 ///\brief	This is an overloaded member function, provided for convenience.
-///             It differs from the above function only in what arguments it
-///             accepts and its return value.
+///		It differs from the above function only in what arguments it
+///		accepts and its return value.
 ///\param	memb_size  - OUT: Size in bytes of each file member
 ///\return	The file access property list for each file member
 ///\exception	H5::PropListIException
@@ -260,7 +261,7 @@ FileAccPropList FileAccPropList::getFamily(hsize_t& memb_size) const
 ///\exception	H5::PropListIException
 ///\par Description
 ///		Temporary - For information, please refer to:
-/// http://hdf.ncsa.uiuc.edu/HDF5/doc/RM_H5P.html#Property-SetFaplSplit
+/// <A HREF="../RM_H5P.html#Property-SetFaplSplit">../RM_H5P.html#Property-SetFaplSplit</A>
 // Programmer:  Binh-Minh Ribler - April, 2004
 //--------------------------------------------------------------------------
 void FileAccPropList::setSplit( FileAccPropList& meta_plist, FileAccPropList& raw_plist, const char* meta_ext, const char* raw_ext ) const
@@ -277,8 +278,8 @@ void FileAccPropList::setSplit( FileAccPropList& meta_plist, FileAccPropList& ra
 //--------------------------------------------------------------------------
 // Function:	FileAccPropList::setSplit
 ///\brief	This is an overloaded member function, provided for convenience.
-///             It differs from the above function only in what arguments it
-///             accepts.
+///		It differs from the above function only in what arguments it
+///		accepts.
 ///\param	meta_plist  - IN: File access plist for the metadata file
 ///\param	raw_plist   - IN: File access plist for the raw data file
 ///\param	meta_ext    - IN: Metadata filename extension as \c string
@@ -286,7 +287,7 @@ void FileAccPropList::setSplit( FileAccPropList& meta_plist, FileAccPropList& ra
 ///\exception	H5::PropListIException
 // Programmer:  Binh-Minh Ribler - April, 2004
 //--------------------------------------------------------------------------
-void FileAccPropList::setSplit( FileAccPropList& meta_plist, FileAccPropList& raw_plist, const string& meta_ext, const string& raw_ext ) const
+void FileAccPropList::setSplit( FileAccPropList& meta_plist, FileAccPropList& raw_plist, const H5std_string& meta_ext, const H5std_string& raw_ext ) const
 {
    setSplit( meta_plist, raw_plist, meta_ext.c_str(), raw_ext.c_str() );
 }
@@ -297,7 +298,7 @@ void FileAccPropList::setSplit( FileAccPropList& meta_plist, FileAccPropList& ra
 ///\brief	Retrieves the streaming I/O driver settings
 ///\return	The streaming I/O file access property list structure
 ///		For detail on this structure, please refer to
-/// http://hdf.ncsa.uiuc.edu/HDF5/doc/RM_H5P.html#Property-SetFaplStream
+/// <A HREF="../RM_H5P.html#Property-SetFaplStream">../RM_H5P.html#Property-SetFaplStream</A>
 ///\exception	H5::PropListIException
 // Programmer:  Binh-Minh Ribler - April, 2004
 //--------------------------------------------------------------------------
@@ -320,7 +321,7 @@ H5FD_stream_fapl_t FileAccPropList::getStream() const
 ///\exception	H5::PropListIException
 ///\par Description
 ///		For detail on \a fapl, please refer to
-/// http://hdf.ncsa.uiuc.edu/HDF5/doc/RM_H5P.html#Property-SetFaplStream
+/// <A HREF="../RM_H5P.html#Property-SetFaplStream">../RM_H5P.html#Property-SetFaplStream</A>
 // Programmer:  Binh-Minh Ribler - April, 2004
 //--------------------------------------------------------------------------
 void FileAccPropList::setStream(H5FD_stream_fapl_t &fapl) const
@@ -359,7 +360,7 @@ size_t FileAccPropList::getSieveBufSize() const
 ///\exception	H5::PropListIException
 ///\par Description
 ///		For detail on data sieving, please refer to
-/// http://hdf.ncsa.uiuc.edu/HDF5/doc/RM_H5P.html#Property-SetSieveBufSize
+/// <A HREF="../RM_H5P.html#Property-SetSieveBufSize">../RM_H5P.html#Property-SetFaplStream../RM_H5P.html#Property-SetFaplStream</A>
 // Programmer:  Binh-Minh Ribler - April, 2004
 //--------------------------------------------------------------------------
 void FileAccPropList::setSieveBufSize(size_t bufsize) const
@@ -379,7 +380,7 @@ void FileAccPropList::setSieveBufSize(size_t bufsize) const
 ///\exception	H5::PropListIException
 ///\par Description
 ///		For more detail, please see the C layer Reference Manual at:
-/// http://hdf.ncsa.uiuc.edu/HDF5/doc/RM_H5P.html#Property-SetMetaBlockSize
+/// <A HREF="../RM_H5P.html#Property-SetMetaBlockSize">../RM_H5P.html#Property-SetMetaBlockSize</A>
 // Programmer:  Binh-Minh Ribler - April, 2004
 //--------------------------------------------------------------------------
 void FileAccPropList::setMetaBlockSize(hsize_t &block_size) const
@@ -419,7 +420,7 @@ hsize_t FileAccPropList::getMetaBlockSize() const
 ///\exception	H5::PropListIException
 ///\par Description
 ///		For detail on \a flags, please refer to
-/// http://hdf.ncsa.uiuc.edu/HDF5/doc/RM_H5P.html#Property-SetFaplStream
+/// <A HREF="../RM_H5P.html#Property-SetFaplStream">../RM_H5P.html#Property-SetFaplStream</A>
 // Programmer:  Binh-Minh Ribler - April, 2004
 //--------------------------------------------------------------------------
 void FileAccPropList::setLog(const char *logfile, unsigned flags, size_t buf_size) const
@@ -441,7 +442,7 @@ void FileAccPropList::setLog(const char *logfile, unsigned flags, size_t buf_siz
 ///\param	buf_size - IN: Size of the logging buffer
 // Programmer:  Binh-Minh Ribler - April, 2004
 //--------------------------------------------------------------------------
-void FileAccPropList::setLog(const string& logfile, unsigned flags, size_t buf_size) const
+void FileAccPropList::setLog(const H5std_string& logfile, unsigned flags, size_t buf_size) const
 {
    setLog(logfile.c_str(), flags, buf_size);
 }
@@ -476,7 +477,7 @@ void FileAccPropList::setSec2() const
 ///		The parameter \a alignment must have a positive value.
 ///
 ///		For detail on \a setting alignment, please refer to
-/// http://hdf.ncsa.uiuc.edu/HDF5/doc/RM_H5P.html#Property-SetAlignment
+/// <A HREF="../RM_H5P.html#Property-SetAlignment">../RM_H5P.html#Property-SetAlignment</A>
 // Programmer:	Binh-Minh Ribler - 2000
 //--------------------------------------------------------------------------
 void FileAccPropList::setAlignment( hsize_t threshold, hsize_t alignment ) const
@@ -513,7 +514,7 @@ void FileAccPropList::getAlignment( hsize_t &threshold, hsize_t &alignment ) con
 ///\exception	H5::PropListIException
 ///\par Description
 ///		More details and valid values for \a dtype can be found at:
-/// http://hdf.ncsa.uiuc.edu/HDF5/doc/RM_H5P.html#Property-SetMultiType
+/// <A HREF="../RM_H5P.html#Property-SetMultiType">../RM_H5P.html#Property-SetMultiType</A>
 // Programmer:  Binh-Minh Ribler - April, 2004
 //--------------------------------------------------------------------------
 void FileAccPropList::setMultiType(H5FD_mem_t dtype) const
@@ -532,7 +533,7 @@ void FileAccPropList::setMultiType(H5FD_mem_t dtype) const
 ///\exception	H5::PropListIException
 ///\par Description
 ///		More details and possible returned values can be found at:
-/// http://hdf.ncsa.uiuc.edu/HDF5/doc/RM_H5P.html#Property-GetMultiType
+/// <A HREF="../RM_H5P.html#Property-GetMultiType">../RM_H5P.html#Property-GetMultiType</A>
 // Programmer:  Binh-Minh Ribler - April, 2004
 //--------------------------------------------------------------------------
 H5FD_mem_t FileAccPropList::getMultiType() const
@@ -553,7 +554,7 @@ H5FD_mem_t FileAccPropList::getMultiType() const
 ///\param	rdcc_nelmts - IN: Number of elements in the raw data chunk cache
 ///\param	rdcc_nbytes - IN: Total size of the raw data chunk cache, in bytes
 ///\param	rdcc_w0 - IN: Preemption policy
-///\exception   H5::PropListIException
+///\exception	H5::PropListIException
 ///\par Description
 ///		The argument \a rdcc_w0 should hold a value between 0 and 1
 ///		inclusive.  This value indicates how much chunks that have
@@ -561,6 +562,7 @@ H5FD_mem_t FileAccPropList::getMultiType() const
 ///		means fully read chunks are treated no differently than other
 ///		chunks (the preemption is strictly LRU) while a value of one
 ///		means fully read chunks are always preempted before other chunks.
+// Programmer:	Binh-Minh Ribler - 2000
 //--------------------------------------------------------------------------
 #ifdef H5_WANT_H5_V1_4_COMPAT
 void FileAccPropList::setCache( int mdc_nelmts, int rdcc_nelmts, size_t rdcc_nbytes, double rdcc_w0 ) const
@@ -678,7 +680,7 @@ H5F_close_degree_t FileAccPropList::getFcloseDegree()
 ///\exception	H5::PropListIException
 ///\par Description
 ///		For detail on \a fapl, please refer to
-/// http://hdf.ncsa.uiuc.edu/HDF5/doc/RM_H5P.html#Property-SetFaplStream
+/// <A HREF="../RM_H5P.html#Property-SetFaplStream">../RM_H5P.html#Property-SetFaplStream</A>
 // Programmer:	Binh-Minh Ribler - 2000
 //--------------------------------------------------------------------------
 void FileAccPropList::setGcReferences( unsigned gc_ref ) const
