@@ -1,5 +1,6 @@
 // C++ informative line for the emacs editor: -*- C++ -*-
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
+ * Copyright by The HDF Group.                                               *
  * Copyright by the Board of Trustees of the University of Illinois.         *
  * All rights reserved.                                                      *
  *                                                                           *
@@ -9,8 +10,8 @@
  * of the source code distribution tree; Copyright.html can be found at the  *
  * root level of an installed copy of the electronic HDF5 document set and   *
  * is linked from the top-level documents page.  It can also be found at     *
- * http://hdf.ncsa.uiuc.edu/HDF5/doc/Copyright.html.  If you do not have     *
- * access to either file, you may request a copy from hdfhelp@ncsa.uiuc.edu. *
+ * http://hdfgroup.org/HDF5/doc/Copyright.html.  If you do not have          *
+ * access to either file, you may request a copy from help@hdfgroup.org.     *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
 #ifndef _H5Group_H
@@ -26,28 +27,31 @@ class H5_DLLCPP Group : public H5Object, public CommonFG {
 	virtual void close();
 
 	// Retrieves the type of object that an object reference points to.
-	H5G_obj_t getObjType(void *ref, H5R_type_t ref_type) const;
+	H5G_obj_t getObjType(void *ref, H5R_type_t ref_type = H5R_OBJECT) const;
 
 	// Retrieves a dataspace with the region pointed to selected.
 	DataSpace getRegion(void *ref, H5R_type_t ref_type = H5R_DATASET_REGION) const;
 
 	// Creates a reference to a named Hdf5 object or to a dataset region
 	// in this object.
-	void* Reference(const char* name, DataSpace& dataspace, H5R_type_t ref_type = H5R_DATASET_REGION) const;
+	void* Reference(const char* name, DataSpace& dataspace, H5R_type_t ref_type = H5R_DATASET_REGION) const; // will be obsolete
 
 	// Creates a reference to a named Hdf5 object in this object.
-	void* Reference(const char* name) const;
-	void* Reference(const string& name) const;
+	void* Reference(const char* name) const; // will be obsolete
+	void* Reference(const H5std_string& name) const; // will be obsolete
 
 	// Returns this class name
-	virtual string fromClass () const { return ("Group"); }
+	virtual H5std_string fromClass () const { return("Group"); }
 
-        // Throw group exception.
-        virtual void throwException(const string func_name, const string msg) const;
+	// Throw group exception.
+	virtual void throwException(const H5std_string& func_name, const H5std_string& msg) const;
 
 	// for CommonFG to get the file id.
 	virtual hid_t getLocId() const;
 
+	// Creates a group by way of dereference.
+	Group(IdComponent& obj, void* ref);
+
 	// default constructor
 	Group();
 
@@ -57,8 +61,8 @@ class H5_DLLCPP Group : public H5Object, public CommonFG {
 	// Destructor
 	virtual ~Group();
 
-        // Creates a copy of an existing group using its id.
-        Group( const hid_t group_id );
+	// Creates a copy of an existing group using its id.
+	Group( const hid_t group_id );
 
 };
 #ifndef H5_NO_NAMESPACE
