@@ -1,4 +1,5 @@
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
+ * Copyright by The HDF Group.                                               *
  * Copyright by the Board of Trustees of the University of Illinois.         *
  * All rights reserved.                                                      *
  *                                                                           *
@@ -8,8 +9,8 @@
  * of the source code distribution tree; Copyright.html can be found at the  *
  * root level of an installed copy of the electronic HDF5 document set and   *
  * is linked from the top-level documents page.  It can also be found at     *
- * http://hdf.ncsa.uiuc.edu/HDF5/doc/Copyright.html.  If you do not have     *
- * access to either file, you may request a copy from hdfhelp@ncsa.uiuc.edu. *
+ * http://hdfgroup.org/HDF5/doc/Copyright.html.  If you do not have          *
+ * access to either file, you may request a copy from help@hdfgroup.org.     *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
 #include <string>
@@ -18,6 +19,7 @@
 #include "H5Exception.h"
 #include "H5Library.h"
 #include "H5IdComponent.h"
+#include "H5DataSpace.h"
 
 #ifndef H5_NO_NAMESPACE
 namespace H5 {
@@ -40,8 +42,8 @@ IdComponent::IdComponent(const hid_t h5_id) : id(h5_id) {}
 //--------------------------------------------------------------------------
 IdComponent::IdComponent( const IdComponent& original )
 {
-   id = original.id;
-   incRefCount(); // increment number of references to this id
+    id = original.id;
+    incRefCount(); // increment number of references to this id
 }
 
 //--------------------------------------------------------------------------
@@ -49,11 +51,11 @@ IdComponent::IdComponent( const IdComponent& original )
 ///\brief	Increment reference counter for a given id.
 // Programmer	Binh-Minh Ribler - May 2005
 //--------------------------------------------------------------------------
-void IdComponent::incRefCount(hid_t obj_id) const
+void IdComponent::incRefCount(const hid_t obj_id) const
 {
     if (p_valid_id(obj_id))
 	if (H5Iinc_ref(obj_id) < 0)
-            throw IdComponentException(inMemFunc("incRefCount"), "incrementing object ref count failed");
+	    throw IdComponentException(inMemFunc("incRefCount"), "incrementing object ref count failed");
 }
 
 //--------------------------------------------------------------------------
@@ -74,10 +76,10 @@ void IdComponent::incRefCount() const
 //		Added the check for ref counter to give a little more info
 //		on why H5Idec_ref fails in some cases - BMR 5/19/2005
 //--------------------------------------------------------------------------
-void IdComponent::decRefCount(hid_t obj_id) const
+void IdComponent::decRefCount(const hid_t obj_id) const
 {
     if (p_valid_id(obj_id))
-        if (H5Idec_ref(obj_id) < 0)
+	if (H5Idec_ref(obj_id) < 0)
 	    if (H5Iget_ref(obj_id) <= 0)
 		throw IdComponentException(inMemFunc("decRefCount"),
 					"object ref count is 0 or negative");
@@ -102,14 +104,14 @@ void IdComponent::decRefCount() const
 ///\return	Reference count
 // Programmer	Binh-Minh Ribler - May 2005
 //--------------------------------------------------------------------------
-int IdComponent::getCounter(hid_t obj_id) const
+int IdComponent::getCounter(const hid_t obj_id) const
 {
     int counter = 0;
     if (p_valid_id(obj_id))
     {
 	counter = H5Iget_ref(obj_id);
 	if (counter < 0)
-            throw IdComponentException(inMemFunc("incRefCount"), "incrementing object ref count failed");
+	    throw IdComponentException(inMemFunc("incRefCount"), "getting object ref count failed - negative");
     }
     return (counter);
 }
@@ -125,6 +127,29 @@ int IdComponent::getCounter() const
     return (getCounter(id));
 }
 
+//--------------------------------------------------------------------------
+// Function:	hdfObjectType
+///\brief	Given an id, returns the type of the object.
+///return	a valid HDF object type, which may be one of the following:
+///		\li \c H5I_FILE
+///		\li \c H5I_GROUP
+///		\li \c H5I_DATATYPE
+///		\li \c H5I_DATASPACE
+///		\li \c H5I_DATASET
+///		\li \c H5I_ATTR
+///		\li or \c H5I_BADID, if no valid type can be determined or the
+///				input object id is invalid.
+// Programmer   Binh-Minh Ribler - Jul, 2005
+//--------------------------------------------------------------------------
+H5I_type_t IdComponent::getHDFObjType(const hid_t obj_id)
+{
+    H5I_type_t id_type = H5Iget_type(obj_id);
+    if (id_type <= H5I_BADID || id_type >= H5I_NGROUPS)
+	return H5I_BADID; // invalid
+    else
+	return id_type; // valid type
+}
+
 //--------------------------------------------------------------------------
 // Function:	IdComponent::operator=
 ///\brief	Assignment operator.
@@ -133,25 +158,31 @@ int IdComponent::getCounter() const
 ///\exception	H5::IdComponentException when attempt to close the HDF5
 ///		object fails
 // Description
-// 		The underlaying reference counting in the C library ensures
-// 		that the current valid id of this object is properly closed.
-//		Copy the id from rhs to this object, then increment the
+//		First, close the current valid id of this object.  Then
+//		copy the id from rhs to this object, and increment the
 //		reference counter of the id to indicate that another object
-//		is referencing it.
+//		is referencing that id.
 // Programmer	Binh-Minh Ribler - 2000
 //--------------------------------------------------------------------------
 IdComponent& IdComponent::operator=( const IdComponent& rhs )
 {
-   // handling references to this id
-   decRefCount();
+    if (this != &rhs)
+    {
+	// handling references to this id
+	try {
+	    close();
+	}
+	catch (Exception close_error) {
+	    throw FileIException(inMemFunc("operator="), close_error.getDetailMsg());
+	}
 
-   // copy the data members from the rhs object
-   id = rhs.id;
+	// copy the data members from the rhs object
+	id = rhs.id;
 
-   // increment the reference counter
-   incRefCount();
-
-   return( *this );
+	// increment the reference counter
+	incRefCount();
+    }
+    return *this;
 }
 
 //--------------------------------------------------------------------------
@@ -166,13 +197,21 @@ IdComponent& IdComponent::operator=( const IdComponent& rhs )
 // 		Then the object's id is reset to the new id.
 // Programmer	Binh-Minh Ribler - 2000
 //--------------------------------------------------------------------------
-void IdComponent::setId( hid_t new_id )
+void IdComponent::setId(const hid_t new_id)
 {
-   // handling references to this id
-   decRefCount();
+    // handling references to this old id
+    try {
+	close();
+    }
+    catch (Exception close_error) {
+	throw IdComponentException(inMemFunc("copy"), close_error.getDetailMsg());
+    }
 
    // reset object's id to the given id
    id = new_id;
+
+   // increment the reference counter of the new id
+   incRefCount();
 }
 
 //--------------------------------------------------------------------------
@@ -183,7 +222,7 @@ void IdComponent::setId( hid_t new_id )
 //--------------------------------------------------------------------------
 hid_t IdComponent::getId () const
 {
-   return( id );
+   return(id);
 }
 
 //--------------------------------------------------------------------------
@@ -191,31 +230,7 @@ hid_t IdComponent::getId () const
 ///\brief	Noop destructor.
 // Programmer	Binh-Minh Ribler - 2000
 //--------------------------------------------------------------------------
-IdComponent::~IdComponent() {
-
-/* uncomment this block and complete it when deciding to use dontAtExit
-   unless the atexit/global destructor problem is fixed, then
-   remove it- BMR 11/14/00
-
-   if( id == NOTATEXIT )
-   {
-      // Call H5Library::close to clean up - temporary solution to avoid the
-      // trouble of atexit/global destructors
-      try {
-         if( H5Library::need_cleanup == true )
-         {
-            H5Library::close();
-            H5Library::need_cleanup = false; // reset the boolean just in case
-         }
-      }
-      // catch failure caused by the H5Library operations
-      catch( LibraryIException error )
-      {
-         error.printError();
-      }
-   }
-*/
-}
+IdComponent::~IdComponent() {}
 
 //
 // Implementation of protected functions for HDF5 Reference Interface
@@ -223,6 +238,26 @@ IdComponent::~IdComponent() {
 //
 
 #ifndef DOXYGEN_SHOULD_SKIP_THIS
+//--------------------------------------------------------------------------
+// Function:	IdComponent::inMemFunc
+///\brief	Makes and returns string "<class-name>::<func_name>"
+///\param	func_name - Name of the function where failure occurs
+// Description
+///		Concatenates the class name of this object with the
+///		passed-in function name to create a string that indicates
+///		where the failure occurs.  The class-name is provided by
+///		fromClass().  This string will be used by a base class when
+///		an exception is thrown.
+// Programmer	Binh-Minh Ribler - Oct 10, 2005
+//--------------------------------------------------------------------------
+H5std_string IdComponent::inMemFunc(const char* func_name) const
+{
+   H5std_string full_name = func_name;
+   full_name.insert(0, "::");
+   full_name.insert(0, fromClass());
+   return (full_name);
+}
+
 //--------------------------------------------------------------------------
 // Function:	IdComponent default constructor - private
 ///\brief	Default constructor.
@@ -231,7 +266,7 @@ IdComponent::~IdComponent() {
 IdComponent::IdComponent() : id(-1) {}
 
 //--------------------------------------------------------------------------
-// Function:	IdComponent::p_get_file_name
+// Function:	IdComponent::p_get_file_name (protected)
 // Purpose:	Gets the name of the file, in which this object belongs.
 // Exception:	H5::IdComponentException
 // Description:
@@ -240,7 +275,7 @@ IdComponent::IdComponent() : id(-1) {}
 // 		H5File and H5Object subclasses.
 // Programmer	Binh-Minh Ribler - Jul, 2004
 //--------------------------------------------------------------------------
-string IdComponent::p_get_file_name() const
+H5std_string IdComponent::p_get_file_name() const
 {
    // Preliminary call to H5Fget_name to get the length of the file name
    ssize_t name_size = H5Fget_name(id, NULL, 0);
@@ -262,7 +297,7 @@ string IdComponent::p_get_file_name() const
    }
 
    // Convert the C file name and return
-   string file_name(name_C);
+   H5std_string file_name(name_C);
    delete []name_C;
    return(file_name);
 }
@@ -274,19 +309,121 @@ string IdComponent::p_get_file_name() const
 //		name - IN: Name of the object to be referenced
 //		dataspace - IN: Dataspace with selection
 //		ref_type - IN: Type of reference; default to \c H5R_DATASET_REGION
-// Return	A reference
 // Exception	H5::IdComponentException
 // Programmer	Binh-Minh Ribler - May, 2004
 //--------------------------------------------------------------------------
-void* IdComponent::p_reference(const char* name, hid_t space_id, H5R_type_t ref_type) const
+void IdComponent::p_reference(void* ref, const char* name, hid_t space_id, H5R_type_t ref_type) const
 {
-   void *ref=NULL;
    herr_t ret_value = H5Rcreate(ref, id, name, ref_type, space_id);
    if (ret_value < 0)
    {
       throw IdComponentException("", "H5Rcreate failed");
    }
-   return(ref);
+}
+
+//--------------------------------------------------------------------------
+// Function:    IdComponent::reference
+///\brief       Creates a reference to an HDF5 object or a dataset region.
+///\param       ref - IN: Reference pointer
+///\param       name - IN: Name of the object to be referenced
+///\param       dataspace - IN: Dataspace with selection
+///\param       ref_type - IN: Type of reference to query, valid values are:
+///             \li \c H5R_OBJECT \tReference is an object reference.
+///             \li \c H5R_DATASET_REGION \tReference is a dataset region
+///                     reference. - this is the default
+///\exception   H5::IdComponentException
+// Programmer   Binh-Minh Ribler - May, 2004
+//--------------------------------------------------------------------------
+void IdComponent::reference(void* ref, const char* name, const DataSpace& dataspace, H5R_type_t ref_type) const
+{
+   try {
+      p_reference(ref, name, dataspace.getId(), ref_type);
+   }
+   catch (IdComponentException E) {
+      throw IdComponentException("IdComponent::reference", E.getDetailMsg());
+   }
+}
+
+//--------------------------------------------------------------------------
+// Function:    IdComponent::reference
+///\brief       This is an overloaded function, provided for your convenience.
+///             It differs from the above function in that it only creates
+///             a reference to an HDF5 object, not to a dataset region.
+///\param       ref - IN: Reference pointer
+///\param       name - IN: Name of the object to be referenced - \c char pointer
+///\exception   H5::IdComponentException
+///\par Description
+//              This function passes H5R_OBJECT and -1 to the protected
+//              function for it to pass to the C API H5Rcreate
+//              to create a reference to the named object.
+// Programmer   Binh-Minh Ribler - May, 2004
+//--------------------------------------------------------------------------
+void IdComponent::reference(void* ref, const char* name) const
+{
+   try {
+      p_reference(ref, name, -1, H5R_OBJECT);
+   }
+   catch (IdComponentException E) {
+      throw IdComponentException("IdComponent::reference", E.getDetailMsg());
+   }
+}
+
+//--------------------------------------------------------------------------
+// Function:    IdComponent::reference
+///\brief       This is an overloaded function, provided for your convenience.
+///             It differs from the above function in that it takes an
+///             \c H5std_string for the object's name.
+///\param       ref - IN: Reference pointer
+///\param       name - IN: Name of the object to be referenced - \c H5std_string
+// Programmer   Binh-Minh Ribler - May, 2004
+//--------------------------------------------------------------------------
+void IdComponent::reference(void* ref, const H5std_string& name) const
+{
+   reference(ref, name.c_str());
+}
+
+//--------------------------------------------------------------------------
+// Function:	IdComponent::p_reference (protected)
+// Purpose	Creates a reference to an HDF5 object or a dataset region.
+// Parameters
+//		name - IN: Name of the object to be referenced
+//		dataspace - IN: Dataspace with selection
+//		ref_type - IN: Type of reference; default to \c H5R_DATASET_REGION
+// Return	A reference
+// Exception	H5::IdComponentException
+// Notes	This function is incorrect, and will be removed in the near
+//		future after notifying users of the new APIs ::reference's.
+//		BMR - Oct 8, 2006
+// Programmer	Binh-Minh Ribler - May, 2004
+//--------------------------------------------------------------------------
+void* IdComponent::p_reference(const char* name, hid_t space_id, H5R_type_t ref_type) const
+{
+   hobj_ref_t ref;
+   herr_t ret_value = H5Rcreate(&ref, id, name, ref_type, space_id);
+   if (ret_value < 0)
+   {
+      throw IdComponentException("", "H5Rcreate failed");
+   }
+   return (reinterpret_cast<void*>(ref));
+}
+
+//--------------------------------------------------------------------------
+// Function:	IdComponent::dereference
+// Purpose	Opens the HDF5 object referenced.
+// Parameters
+//		obj - IN: Dataset reference object is in or location of
+//                            object that the dataset is located within.
+//		ref - IN: Reference pointer
+// Exception	H5::IdComponentException
+// Programmer	Binh-Minh Ribler - Oct, 2006
+//--------------------------------------------------------------------------
+void IdComponent::dereference(IdComponent& obj, void* ref)
+{
+   id = H5Rdereference(obj.getId(), H5R_OBJECT, ref);
+   if (id < 0)
+   {
+      throw IdComponentException("", "H5Rdereference failed");
+   }
 }
 
 //--------------------------------------------------------------------------
@@ -305,10 +442,19 @@ void* IdComponent::p_reference(const char* name, hid_t space_id, H5R_type_t ref_
 //--------------------------------------------------------------------------
 H5G_obj_t IdComponent::p_get_obj_type(void *ref, H5R_type_t ref_type) const
 {
+#ifdef H5_WANT_H5_V1_4_COMPAT
+   H5G_obj_t obj_type = H5Rget_object_type(id, ref);
+#else
    H5G_obj_t obj_type = H5Rget_obj_type(id, ref_type, ref);
+#endif
+
    if (obj_type == H5G_UNKNOWN)
    {
-      throw IdComponentException("", "H5R_get_obj_type failed");
+#ifdef H5_WANT_H5_V1_4_COMPAT
+      throw IdComponentException("", "H5Rget_object_type failed");
+#else
+      throw IdComponentException("", "H5Rget_obj_type failed");
+#endif
    }
    return(obj_type);
 }
@@ -345,7 +491,7 @@ hid_t IdComponent::p_get_region(void *ref, H5R_type_t ref_type) const
 // Return	true if id is valid, false, otherwise
 // Programmer	Binh-Minh Ribler - May, 2005
 //--------------------------------------------------------------------------
-bool IdComponent::p_valid_id(hid_t obj_id) const
+bool IdComponent::p_valid_id(const hid_t obj_id) const
 {
     H5I_type_t id_type = H5Iget_type(obj_id);
     if (id_type <= H5I_BADID || id_type >= H5I_NGROUPS)
@@ -354,26 +500,6 @@ bool IdComponent::p_valid_id(hid_t obj_id) const
 	return true;
 }
 
-//--------------------------------------------------------------------------
-// Function:	IdComponent::inMemFunc
-///\brief	Makes and returns string "<class-name>::<func_name>"
-///\param	func_name - Name of the function where failure occurs
-// Description
-///		Concatenates the class name of this object with the
-///		passed-in function name to create a string that indicates
-///		where the failure occurs.  The class-name is provided by
-///		fromClass().  This string will be used by a base class when
-///		an exception is thrown.
-// Programmer	Binh-Minh Ribler - Oct 10, 2005
-//--------------------------------------------------------------------------
-string IdComponent::inMemFunc(const char* func_name) const
-{
-   string full_name = func_name;
-   full_name.insert(0, "::");
-   full_name.insert(0, fromClass());
-   return (full_name);
-}
-
 #endif // DOXYGEN_SHOULD_SKIP_THIS
 
 #ifndef H5_NO_NAMESPACE
