@@ -1,5 +1,6 @@
 // C++ informative line for the emacs editor: -*- C++ -*-
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
+ * Copyright by The HDF Group.                                               *
  * Copyright by the Board of Trustees of the University of Illinois.         *
  * All rights reserved.                                                      *
  *                                                                           *
@@ -9,42 +10,50 @@
  * of the source code distribution tree; Copyright.html can be found at the  *
  * root level of an installed copy of the electronic HDF5 document set and   *
  * is linked from the top-level documents page.  It can also be found at     *
- * http://hdf.ncsa.uiuc.edu/HDF5/doc/Copyright.html.  If you do not have     *
- * access to either file, you may request a copy from hdfhelp@ncsa.uiuc.edu. *
+ * http://hdfgroup.org/HDF5/doc/Copyright.html.  If you do not have          *
+ * access to either file, you may request a copy from help@hdfgroup.org.     *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
 #ifndef _IdComponent_H
 #define _IdComponent_H
 
-// IdComponent provides a mechanism to handle
-// reference counting for an identifier of any HDF5 object.
+// IdComponent represents an HDF5 object that has an identifier.
 
 #ifndef H5_NO_NAMESPACE
 namespace H5 {
-#ifndef H5_NO_STD
-    using std::string;
-#endif  // H5_NO_STD
 #endif
 
+class DataSpace;
 class H5_DLLCPP IdComponent {
    public:
 	// Increment reference counter.
-	void incRefCount(hid_t obj_id) const;
+	void incRefCount(const hid_t obj_id) const;
 	void incRefCount() const;
 
 	// Decrement reference counter.
-	void decRefCount(hid_t obj_id) const;
+	void decRefCount(const hid_t obj_id) const;
 	void decRefCount() const;
 
 	// Get the reference counter to this identifier.
-	int getCounter(hid_t obj_id) const;
+	int getCounter(const hid_t obj_id) const;
 	int getCounter() const;
 
-	// Assignment operator
+	// Returns an HDF5 object type, given the object id.
+	static H5I_type_t getHDFObjType(const hid_t obj_id);
+
+	// Assignment operator.
 	IdComponent& operator=( const IdComponent& rhs );
 
+        void reference(void* ref, const char* name, const DataSpace& dataspace,
+                        H5R_type_t ref_type = H5R_DATASET_REGION) const;
+        void reference(void* ref, const char* name) const;
+        void reference(void* ref, const H5std_string& name) const;
+
+	// Open a referenced HDF5 object.
+	void dereference(IdComponent& obj, void* ref);
+
 	// Sets the identifier of this object to a new value.
-	void setId( hid_t new_id );
+	void setId(const hid_t new_id);
 
 	// Creates an object to hold an HDF5 identifier.
 	IdComponent( const hid_t h5_id );
@@ -60,14 +69,14 @@ class H5_DLLCPP IdComponent {
 	// subclasses.
 	virtual void close() = 0;
 
-#endif // DOXYGEN_SHOULD_SKIP_THIS
-
 	// Makes and returns the string "<class-name>::<func_name>";
 	// <class-name> is returned by fromClass().
-	string inMemFunc(const char* func_name) const;
+	H5std_string inMemFunc(const char* func_name) const;
 
 	// Returns this class name.
-	virtual string fromClass() const {return ("IdComponent");}
+	virtual H5std_string fromClass() const { return("IdComponent");}
+
+#endif // DOXYGEN_SHOULD_SKIP_THIS
 
 	// Destructor
 	virtual ~IdComponent();
@@ -80,17 +89,14 @@ class H5_DLLCPP IdComponent {
 	IdComponent();
 
 	// Gets the name of the file, in which an HDF5 object belongs.
-#ifndef H5_NO_STD
-	std::string p_get_file_name() const;
-#else
-	string p_get_file_name() const;
-#endif  // H5_NO_STD
+	H5std_string p_get_file_name() const;
 
 	// Gets the id of the H5 file in which the given object is located.
 	hid_t p_get_file_id();
 
 	// Creates a reference to an HDF5 object or a dataset region.
-	void* p_reference(const char* name, hid_t space_id, H5R_type_t ref_type) const;
+	void p_reference(void* ref, const char* name, hid_t space_id, H5R_type_t ref_type) const;
+	void* p_reference(const char* name, hid_t space_id, H5R_type_t ref_type) const; // will be removed
 
 	// Retrieves the type of object that an object reference points to.
 	H5G_obj_t p_get_obj_type(void *ref, H5R_type_t ref_type) const;
@@ -99,7 +105,7 @@ class H5_DLLCPP IdComponent {
 	hid_t p_get_region(void *ref, H5R_type_t ref_type) const;
 
 	// Verifies that the given id is valid.
-	bool p_valid_id(hid_t obj_id) const;
+	bool p_valid_id(const hid_t obj_id) const;
 
 #endif // DOXYGEN_SHOULD_SKIP_THIS
 
