@@ -1,4 +1,5 @@
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
+ * Copyright by The HDF Group.                                               *
  * Copyright by the Board of Trustees of the University of Illinois.         *
  * All rights reserved.                                                      *
  *                                                                           *
@@ -8,8 +9,8 @@
  * of the source code distribution tree; Copyright.html can be found at the  *
  * root level of an installed copy of the electronic HDF5 document set and   *
  * is linked from the top-level documents page.  It can also be found at     *
- * http://hdf.ncsa.uiuc.edu/HDF5/doc/Copyright.html.  If you do not have     *
- * access to either file, you may request a copy from hdfhelp@ncsa.uiuc.edu. *
+ * http://hdfgroup.org/HDF5/doc/Copyright.html.  If you do not have          *
+ * access to either file, you may request a copy from help@hdfgroup.org.     *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
 /*****************************************************************************
@@ -27,8 +28,15 @@
 #endif
 #include <string>
 
+#ifndef H5_NO_NAMESPACE
+#ifndef H5_NO_STD
+    using std::cerr;
+    using std::endl;
+#endif  // H5_NO_STD
+#endif
+
 #include "h5test.h"
-#include "H5Exception.h"
+#include "H5Cpp.h"	// C++ API header file
 #include "h5cpputil.h"
 
 #ifndef H5_NO_NAMESPACE
@@ -54,7 +62,7 @@ using namespace H5;
  *
  *-------------------------------------------------------------------------
  */
-int test_report( int nerrors, const string& testname )
+int test_report( int nerrors, const H5std_string& testname )
 {
    if (nerrors)
    {
@@ -89,13 +97,46 @@ int test_report( int nerrors, const string& testname )
 void issue_fail_msg(const char* where, int line, const char* file_name,
 		    const char* message)
 {
-    if (GetTestVerbosity()>=VERBO_HI)
+    //if (GetTestVerbosity()>=VERBO_HI)
     {
-        cerr << "--> From " << where << " at line " << line
+        cerr << "ERROR>>> From " << where << " at line " << line
              << " in " << file_name << " - " << message << endl << endl;
     }
 }
 
+/*-------------------------------------------------------------------------
+ * Function:	check_values
+ *
+ * Purpose:	Checks a read value against the written value.  If they are
+ *		different, the function will print out a message and the
+ *		different values.  This function is made to reuse the code
+ *		segment that is used in various places throughout
+ *		the test code.  Where the C version of this code segment
+ *		"goto error," this function will return -1.
+ *
+ * Return:	Success:        0
+ *
+ *		Failure:        -1
+ *
+ * Programmer:	Binh-Minh Ribler (using C code segment for checking values)
+ *		Friday, February 6, 2001
+ *
+ * Modifications:
+ *
+ *-------------------------------------------------------------------------
+ */
+int check_values (hsize_t i, hsize_t j, int apoint, int acheck)
+{
+    if (apoint != acheck)
+    {
+	cerr << "    Read different values than written.\n" << endl;
+	cerr << "    At index " << (unsigned long)i << "," <<
+	(unsigned long)j << endl;
+	return -1;
+    }
+    return 0;
+} // check_values
+
 //--------------------------------------------------------------------------
 // Function:    InvalidActionException default constructor
 //--------------------------------------------------------------------------
@@ -111,7 +152,7 @@ InvalidActionException::InvalidActionException():Exception(){}
 //		func_name - IN: Name of the function where failure should occur
 //		message   - IN: Message
 //--------------------------------------------------------------------------
-InvalidActionException::InvalidActionException(const string func_name, const string message) : Exception(func_name, message) {}
+InvalidActionException::InvalidActionException(const H5std_string func_name, const H5std_string message) : Exception(func_name, message) {}
 
 //--------------------------------------------------------------------------
 // Function:    InvalidActionException destructor
