@@ -1,4 +1,5 @@
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
+ * Copyright by The HDF Group.                                               *
  * Copyright by the Board of Trustees of the University of Illinois.         *
  * All rights reserved.                                                      *
  *                                                                           *
@@ -8,8 +9,8 @@
  * of the source code distribution tree; Copyright.html can be found at the  *
  * root level of an installed copy of the electronic HDF5 document set and   *
  * is linked from the top-level documents page.  It can also be found at     *
- * http://hdf.ncsa.uiuc.edu/HDF5/doc/Copyright.html.  If you do not have     *
- * access to either file, you may request a copy from hdfhelp@ncsa.uiuc.edu. *
+ * http://hdfgroup.org/HDF5/doc/Copyright.html.  If you do not have          *
+ * access to either file, you may request a copy from help@hdfgroup.org.     *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
 /*****************************************************************************
@@ -30,13 +31,14 @@ using namespace H5;
 #endif
 
 #ifndef H5_NO_STD
-int test_report (int, const std::string&);
 using std::cerr;
 using std::endl;
-#else
-int test_report (int, const string&);
 #endif
 
+#define SUBTEST(WHAT)   {printf("   Subtest: %-52s",WHAT); fflush(stdout);}
+
+int check_values (hsize_t i, hsize_t j, int apoint, int acheck);
+int test_report (int, const H5std_string&);
 void issue_fail_msg(const char* where, int line, const char* file_name,
 		    const char* message="");
 
@@ -69,11 +71,56 @@ template <class Type1, class Type2>
     }
 }
 
+template <class Type1, class Type2>
+    void verify_val_noteq(Type1 x, Type2 value, const char* where, int line, const char* file_name)
+{
+    if (GetTestVerbosity()>=VERBO_HI)
+    {
+	cerr << "   Call to routine: " << where << " at line " << line
+	     << " in " << file_name <<  " had value " << x << endl;
+    }
+    if (x == value)
+    {
+	cerr << "*** UNEXPECTED VALUE from " << where << " should not be "
+	     << value << " at line " << line << " in " << file_name << endl;
+	IncTestNumErrs();
+    }
+}
+
 class InvalidActionException : public Exception {
    public:
-	InvalidActionException(const string func_name, const string message = DEFAULT_MSG);
+	InvalidActionException(const H5std_string func_name, const H5std_string message = DEFAULT_MSG);
 	InvalidActionException();
 	virtual ~InvalidActionException();
 };
 
+/* Prototypes for the test routines */
+void test_attr(void);
+void test_compound(void);
+void test_file(void);
+void test_filters(void);
+void test_h5s(void);
+void test_reference(void);
+void test_types(void);
+void test_vlstrings(void);
+
+/* Prototypes for the cleanup routines */
+void cleanup_attr(void);
+void cleanup_compound(void);
+void cleanup_file(void);
+void cleanup_filters(void);
+void cleanup_h5s(void);
+void cleanup_reference(void);
+void cleanup_types(void);
+void cleanup_vlstrings(void);
+/* not yet
+void cleanup_select(void);
+void cleanup_time(void);
+void cleanup_vltypes(void);
+void cleanup_iterate(void);
+void cleanup_array(void);
+void cleanup_genprop(void);
+void cleanup_misc(void);
+*/
+
 #endif
