@@ -1,4 +1,5 @@
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
+ * Copyright by The HDF Group.                                               *
  * Copyright by the Board of Trustees of the University of Illinois.         *
  * All rights reserved.                                                      *
  *                                                                           *
@@ -8,8 +9,8 @@
  * of the source code distribution tree; Copyright.html can be found at the  *
  * root level of an installed copy of the electronic HDF5 document set and   *
  * is linked from the top-level documents page.  It can also be found at     *
- * http://hdf.ncsa.uiuc.edu/HDF5/doc/Copyright.html.  If you do not have     *
- * access to either file, you may request a copy from hdfhelp@ncsa.uiuc.edu. *
+ * http://hdfgroup.org/HDF5/doc/Copyright.html.  If you do not have          *
+ * access to either file, you may request a copy from help@hdfgroup.org.     *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
 #include "H5IM.h"
@@ -527,7 +528,6 @@ herr_t H5IMlink_palette( hid_t loc_id,
                          const char *pal_name )
 
 {
-
  hid_t       image_id;
  hid_t       attr_type;
  hid_t       attr_id;
@@ -539,7 +539,7 @@ herr_t H5IMlink_palette( hid_t loc_id,
  hsize_t     dim_ref;
  int         ok_pal;
 
- /* The image dataset may or not have the attribute "PALETTE"
+ /* The image dataset may or may not have the attribute "PALETTE"
   * First we try to open to see if it is already there; if not, it is created.
   * If it exists, the array of references is extended to hold the reference
   * to the new palette
@@ -552,10 +552,12 @@ herr_t H5IMlink_palette( hid_t loc_id,
  /* Try to find the attribute "PALETTE" on the >>image<< dataset */
  ok_pal = H5LT_find_attribute( image_id, "PALETTE" );
 
- /* It does not exist. We create the attribute and one reference */
+/*-------------------------------------------------------------------------
+ * It does not exist. We create the attribute and one reference
+ *-------------------------------------------------------------------------
+ */
  if ( ok_pal == 0 )
  {
-
   if ( (attr_space_id = H5Screate( H5S_SCALAR )) < 0 )
    goto out;
 
@@ -575,86 +577,83 @@ herr_t H5IMlink_palette( hid_t loc_id,
   if ( H5Awrite( attr_id, attr_type, &ref ) < 0 )
    goto out;
 
+  /* close */
   if ( H5Sclose( attr_space_id ) < 0 )
    goto out;
-
- }
-
- /* The attribute already exists, open it */
-
- else if ( ok_pal ==  1 )
-
- {
-
-  if ( (attr_id = H5Aopen_name( image_id, "PALETTE" )) < 0 )
-   goto out;
-
-  if ( (attr_type = H5Aget_type( attr_id )) < 0 )
-   goto out;
-
-  if ( (attr_class = H5Tget_class( attr_type )) < 0 )
-   goto out;
-
-  /* Check if it is really a reference */
-
-  if ( attr_class == H5T_REFERENCE )
-  {
-
-   /* Get and save the old reference(s) */
-
-   if ( (attr_space_id = H5Aget_space( attr_id )) < 0 )
-    goto out;
-
-   n_refs = H5Sget_simple_extent_npoints( attr_space_id );
-
-   dim_ref = n_refs + 1;
-
-   refbuf = malloc( sizeof(hobj_ref_t) * (int)dim_ref );
-
-   if ( H5Aread( attr_id, attr_type, refbuf ) < 0 )
-    goto out;
-
-   if ( H5Sclose( attr_space_id ) < 0 )
-    goto out;
-
-   /* The attribute must be deleted, in order to the new one can reflect the changes*/
-   if ( H5Adelete( image_id, "PALETTE" ) < 0 )
-    goto out;
-
-   /* Create a new reference for this palette. */
-   if ( H5Rcreate( &ref, loc_id, pal_name, H5R_OBJECT, -1 ) < 0 )
-    goto out;
-
-   refbuf[n_refs] = ref;
-
-   /* Create the data space for the new references */
-   if ( (attr_space_id = H5Screate_simple( 1, &dim_ref, NULL )) < 0 )
-    goto out;
-
-   /* Create the attribute again with the changes of space */
-   if ( (attr_id = H5Acreate( image_id, "PALETTE", attr_type, attr_space_id, H5P_DEFAULT )) < 0 )
-    goto out;
-
-    /* Write the attribute with the new references */
-   if ( H5Awrite( attr_id, attr_type, refbuf ) < 0 )
-    goto out;
-
-   if ( H5Sclose( attr_space_id ) < 0 )
-    goto out;
-
-   free( refbuf );
-
-  } /* H5T_REFERENCE */
-
   if ( H5Tclose( attr_type ) < 0 )
    goto out;
-
-  /* Close the attribute. */
   if ( H5Aclose( attr_id ) < 0 )
    goto out;
 
  }
 
+/*-------------------------------------------------------------------------
+ * The attribute already exists, open it
+ *-------------------------------------------------------------------------
+ */
+ else if ( ok_pal ==  1 )
+  
+ {
+  if ( (attr_id = H5Aopen_name( image_id, "PALETTE" )) < 0 )
+   goto out;
+  
+  if ( (attr_type = H5Aget_type( attr_id )) < 0 )
+   goto out;
+  
+  if ( (attr_class = H5Tget_class( attr_type )) < 0 )
+   goto out;
+  
+  /* Get and save the old reference(s) */
+  if ( (attr_space_id = H5Aget_space( attr_id )) < 0 )
+   goto out;
+  
+  n_refs = H5Sget_simple_extent_npoints( attr_space_id );
+  
+  dim_ref = n_refs + 1;
+  
+  refbuf = malloc( sizeof(hobj_ref_t) * (int)dim_ref );
+  
+  if ( H5Aread( attr_id, attr_type, refbuf ) < 0 )
+   goto out;
+ 
+  /* The attribute must be deleted, in order to the new one can reflect the changes*/
+  if ( H5Adelete( image_id, "PALETTE" ) < 0 )
+   goto out;
+  
+  /* Create a new reference for this palette. */
+  if ( H5Rcreate( &ref, loc_id, pal_name, H5R_OBJECT, -1 ) < 0 )
+   goto out;
+  
+  refbuf[n_refs] = ref;
+  
+  /* Create the data space for the new references */
+  if ( H5Sclose( attr_space_id ) < 0 )
+   goto out;
+  
+  if ( (attr_space_id = H5Screate_simple( 1, &dim_ref, NULL )) < 0 )
+   goto out;
+  
+  /* Create the attribute again with the changes of space */
+  if ( H5Aclose( attr_id ) < 0 )
+   goto out;
+
+  if ( (attr_id = H5Acreate( image_id, "PALETTE", attr_type, attr_space_id, H5P_DEFAULT )) < 0 )
+   goto out;
+  
+  /* Write the attribute with the new references */
+  if ( H5Awrite( attr_id, attr_type, refbuf ) < 0 )
+   goto out;
+  
+  /* close */
+  if ( H5Sclose( attr_space_id ) < 0 )
+   goto out;
+  if ( H5Aclose( attr_id ) < 0 )
+   goto out;
+  
+  free( refbuf );
+ 
+ } /* ok_pal ==  1 */
+
   /* Close the image dataset. */
  if ( H5Dclose( image_id ) < 0 )
   return -1;
@@ -663,11 +662,13 @@ herr_t H5IMlink_palette( hid_t loc_id,
 
 out:
  H5Dclose( image_id );
+ H5Sclose( attr_space_id );
+ H5Tclose( attr_type );
+ H5Aclose( attr_id );
  return -1;
 }
 
 
-
 /*-------------------------------------------------------------------------
  * Function: H5IMunlink_palette
  *
@@ -873,9 +874,9 @@ out:
  */
 
 herr_t H5IMget_palette_info( hid_t loc_id,
-                        const char *image_name,
-                        int pal_number,
-                        hsize_t *pal_dims )
+                             const char *image_name,
+                             int pal_number,
+                             hsize_t *pal_dims )
 {
  hid_t      image_id;
  int        has_pal;
@@ -889,91 +890,82 @@ herr_t H5IMget_palette_info( hid_t loc_id,
  hid_t      pal_id;
  hid_t      pal_space_id;
  hsize_t    pal_maxdims[2];
-
+ 
  /* Open the dataset. */
  if ( (image_id = H5Dopen( loc_id, image_name )) < 0 )
   return -1;
-
+ 
  /* Try to find the attribute "PALETTE" on the >>image<< dataset */
  has_pal = H5IM_find_palette( image_id );
-
+ 
  if ( has_pal ==  1 )
  {
-
   if ( (attr_id = H5Aopen_name( image_id, "PALETTE" )) < 0 )
    goto out;
-
+  
   if ( (attr_type = H5Aget_type( attr_id )) < 0 )
    goto out;
-
+  
   if ( (attr_class = H5Tget_class( attr_type )) < 0 )
    goto out;
-
-  /* Check if it is really a reference */
-
-  if ( attr_class == H5T_REFERENCE )
-  {
-
-   /* Get the reference(s) */
-
-   if ( (attr_space_id = H5Aget_space( attr_id )) < 0 )
-    goto out;
-
-   n_refs = H5Sget_simple_extent_npoints( attr_space_id );
-
-   dim_ref = n_refs;
-
-   refbuf = malloc( sizeof(hobj_ref_t) * (int)dim_ref );
-
-   if ( H5Aread( attr_id, attr_type, refbuf ) < 0 )
-    goto out;
-
- /* Get the actual palette */
-
+  
+  /* Get the reference(s) */
+  if ( (attr_space_id = H5Aget_space( attr_id )) < 0 )
+   goto out;
+  
+  n_refs = H5Sget_simple_extent_npoints( attr_space_id );
+  
+  dim_ref = n_refs;
+  
+  refbuf = malloc( sizeof(hobj_ref_t) * (int)dim_ref );
+  
+  if ( H5Aread( attr_id, attr_type, refbuf ) < 0 )
+   goto out;
+  
+  /* Get the actual palette */
   if ( (pal_id = H5Rdereference( image_id, H5R_OBJECT, &refbuf[pal_number] )) < 0 )
-    goto out;
-
+   goto out;
+  
   if ( (pal_space_id = H5Dget_space( pal_id )) < 0 )
    goto out;
-
+  
   if ( H5Sget_simple_extent_ndims( pal_space_id ) < 0 )
    goto out;
-
+  
   if ( H5Sget_simple_extent_dims( pal_space_id, pal_dims, pal_maxdims ) < 0 )
    goto out;
-
+  
+  /* close */
+  if (H5Dclose(pal_id)<0)
+   goto out;
   if ( H5Sclose( pal_space_id ) < 0 )
    goto out;
-
   if ( H5Sclose( attr_space_id ) < 0 )
    goto out;
-
-   free( refbuf );
-
-  } /* H5T_REFERENCE */
-
   if ( H5Tclose( attr_type ) < 0 )
    goto out;
-
-  /* Close the attribute. */
   if ( H5Aclose( attr_id ) < 0 )
    goto out;
-
+  free( refbuf );
+  
+   
  }
-
-	/* Close the image dataset. */
+ 
+ /* Close the image dataset. */
  if ( H5Dclose( image_id ) < 0 )
   return -1;
-
+ 
  return 0;
-
+ 
 out:
  H5Dclose( image_id );
+ H5Sclose( attr_space_id );
+ H5Tclose( attr_type );
+ H5Aclose( attr_id );
  return -1;
-
+ 
 }
 
-
 /*-------------------------------------------------------------------------
  * Function: H5IMget_palette
  *
@@ -1019,61 +1011,49 @@ herr_t H5IMget_palette( hid_t loc_id,
 
  if ( has_pal ==  1 )
  {
-
   if ( (attr_id = H5Aopen_name( image_id, "PALETTE" )) < 0 )
    goto out;
-
+  
   if ( (attr_type = H5Aget_type( attr_id )) < 0 )
    goto out;
-
+  
   if ( (attr_class = H5Tget_class( attr_type )) < 0 )
    goto out;
+  
+  /* Get the reference(s) */
+  if ( (attr_space_id = H5Aget_space( attr_id )) < 0 )
+   goto out;
+  
+  n_refs = H5Sget_simple_extent_npoints( attr_space_id );
+  
+  dim_ref = n_refs;
+  
+  refbuf = malloc( sizeof(hobj_ref_t) * (int)dim_ref );
+  
+  if ( H5Aread( attr_id, attr_type, refbuf ) < 0 )
+   goto out;
+  
+  /* Get the palette id */
+  if ( (pal_id = H5Rdereference( image_id, H5R_OBJECT, &refbuf[pal_number] )) < 0 )
+   goto out;
+  
+  /* Read the palette dataset */
+  if ( H5Dread( pal_id, H5Dget_type(pal_id), H5S_ALL, H5S_ALL, H5P_DEFAULT, pal_data ) < 0 )
+   goto out;
 
-  /* Check if it is really a reference */
-
-  if ( attr_class == H5T_REFERENCE )
-  {
-
-   /* Get the reference(s) */
-
-   if ( (attr_space_id = H5Aget_space( attr_id )) < 0 )
-    goto out;
-
-   n_refs = H5Sget_simple_extent_npoints( attr_space_id );
-
-   dim_ref = n_refs;
-
-   refbuf = malloc( sizeof(hobj_ref_t) * (int)dim_ref );
-
-   if ( H5Aread( attr_id, attr_type, refbuf ) < 0 )
-    goto out;
-
-   /* Get the palette id */
-   if ( (pal_id = H5Rdereference( image_id, H5R_OBJECT, &refbuf[pal_number] )) < 0 )
-    goto out;
-
-   /* Read the palette dataset */
-   if ( H5Dread( pal_id, H5Dget_type(pal_id), H5S_ALL, H5S_ALL, H5P_DEFAULT, pal_data ) < 0 )
-    goto out;
-
-   if ( H5Sclose( attr_space_id ) < 0 )
-    goto out;
-
-   free( refbuf );
-
-  } /* H5T_REFERENCE */
-
+  /* close */
+  if (H5Dclose(pal_id)<0)
+   goto out;
+  if ( H5Sclose( attr_space_id ) < 0 )
+   goto out;
   if ( H5Tclose( attr_type ) < 0 )
    goto out;
-
-  /* Close the attribute. */
   if ( H5Aclose( attr_id ) < 0 )
    goto out;
-
+  free( refbuf );
  }
 
-
-     /* Close the image dataset. */
+ /* Close the image dataset. */
  if ( H5Dclose( image_id ) < 0 )
   return -1;
 
@@ -1081,6 +1061,9 @@ herr_t H5IMget_palette( hid_t loc_id,
 
 out:
  H5Dclose( image_id );
+ H5Sclose( attr_space_id );
+ H5Tclose( attr_type );
+ H5Aclose( attr_id );
  return -1;
 
 }
