@@ -1,4 +1,5 @@
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
+ * Copyright by The HDF Group.                                               *
  * Copyright by the Board of Trustees of the University of Illinois.         *
  * All rights reserved.                                                      *
  *                                                                           *
@@ -8,8 +9,8 @@
  * of the source code distribution tree; Copyright.html can be found at the  *
  * root level of an installed copy of the electronic HDF5 document set and   *
  * is linked from the top-level documents page.  It can also be found at     *
- * http://hdf.ncsa.uiuc.edu/HDF5/doc/Copyright.html.  If you do not have     *
- * access to either file, you may request a copy from hdfhelp@ncsa.uiuc.edu. *
+ * http://hdfgroup.org/HDF5/doc/Copyright.html.  If you do not have          *
+ * access to either file, you may request a copy from help@hdfgroup.org.     *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
 #include "H5LT.h"
@@ -495,9 +496,9 @@ herr_t H5LTmake_dataset_string(hid_t loc_id,
 {
 
  hid_t   did=-1;
-	hid_t   sid=-1;
-	hid_t   tid;
-	size_t  size;
+ hid_t   sid=-1;
+ hid_t   tid;
+ size_t  size;
 
  /* create a string data type */
  if ( (tid = H5Tcopy( H5T_C_S1 )) < 0 )
@@ -532,7 +533,7 @@ herr_t H5LTmake_dataset_string(hid_t loc_id,
   return -1;
  if ( H5Sclose(sid) < 0 )
   return -1;
-	if ( H5Tclose(tid) < 0 )
+ if ( H5Tclose(tid) < 0 )
   goto out;
 
  return 0;
@@ -848,13 +849,13 @@ herr_t H5LTread_dataset_string( hid_t loc_id,
                                 char *buf )
 {
  hid_t   did;
-	hid_t   tid;
+ hid_t   tid;
 
  /* Open the dataset. */
  if ( (did = H5Dopen( loc_id, dset_name )) < 0 )
   return -1;
 
-	if ( (tid = H5Dget_type(did)) < 0 )
+ if ( (tid = H5Dget_type(did)) < 0 )
   goto out;
 
  /* Read */
@@ -864,14 +865,14 @@ herr_t H5LTread_dataset_string( hid_t loc_id,
  /* close */
  if ( H5Dclose(did) )
   goto out;
-	if ( H5Tclose(tid) )
+ if ( H5Tclose(tid) )
   return -1;
 
  return 0;
 
 out:
  H5Dclose( did );
-	H5Tclose( tid );
+ H5Tclose( tid );
  return -1;
 
 }
@@ -938,6 +939,7 @@ out:
  * Programmer: Pedro Vicente, pvn@ncsa.uiuc.edu
  *
  * Date: September 4, 2001
+ *  Modified: February 28, 2006: checked for NULL parameters
  *
  *-------------------------------------------------------------------------
  */
@@ -952,36 +954,41 @@ herr_t H5LTget_dataset_info( hid_t loc_id,
  hid_t       tid;
  hid_t       sid;
 
- /* Open the dataset. */
+ /* open the dataset. */
  if ( (did = H5Dopen( loc_id, dset_name )) < 0 )
   return -1;
 
- /* Get an identifier for the datatype. */
+ /* get an identifier for the datatype. */
  tid = H5Dget_type( did );
 
- /* Get the class. */
- *type_class = H5Tget_class( tid );
+ /* get the class. */
+ if (type_class!=NULL)
+  *type_class = H5Tget_class( tid );
 
- /* Get the size. */
- *type_size = H5Tget_size( tid );
+ /* get the size. */
+ if (type_size!=NULL)
+  *type_size = H5Tget_size( tid );
 
-  /* Get the dataspace handle */
- if ( (sid = H5Dget_space( did )) < 0 )
-  goto out;
+ if (dims!=NULL)
+ {
+  /* get the dataspace handle */
+  if ( (sid = H5Dget_space( did )) < 0 )
+   goto out;
+  
+  /* get dimensions */
+  if ( H5Sget_simple_extent_dims( sid, dims, NULL) < 0 )
+   goto out;
+  
+  /* terminate access to the dataspace */
+  if ( H5Sclose( sid ) < 0 )
+   goto out;
+ }
 
- /* Get dimensions */
- if ( H5Sget_simple_extent_dims( sid, dims, NULL) < 0 )
-  goto out;
-
- /* Terminate access to the dataspace */
- if ( H5Sclose( sid ) < 0 )
-  goto out;
-
-  /* Release the datatype. */
+ /* release the datatype. */
  if ( H5Tclose( tid ) )
   return -1;
 
- /* End access to the dataset */
+ /* end access to the dataset */
  if ( H5Dclose( did ) )
   return -1;
 
@@ -1109,7 +1116,7 @@ herr_t H5LTset_attribute_string( hid_t loc_id,
  hid_t      obj_id;
  int        has_attr;
  H5G_stat_t statbuf;
-	size_t     attr_size;
+ size_t     attr_size;
 
 
  /* Get the type of object */
@@ -1897,134 +1904,6 @@ out:
 }
 
 
-/*-------------------------------------------------------------------------
- *
- * General functions
- *
- *-------------------------------------------------------------------------
- */
-
-/*-------------------------------------------------------------------------
- * Function: H5LTcreate_compound_type
- *
- * Purpose:
- *
- * Return: Success: 0, Failure: -1
- *
- * Programmer: Pedro Vicente, pvn@ncsa.uiuc.edu
- *
- * Date: September 18, 2001
- *
- * Comments:
- *
- * Modifications:
- *
- *
- *-------------------------------------------------------------------------
- */
-
-hid_t H5LTcreate_compound_type( hsize_t nfields, size_t size, const char *field_names[],
-                                const size_t *field_offset, const hid_t *field_types )
-{
-
- hid_t   tid;
- hsize_t i;
-
- /* Create the memory data type. */
- if ((tid = H5Tcreate (H5T_COMPOUND, size )) < 0 )
-  goto out;
-
- /* Insert fields. */
- for ( i = 0; i < nfields; i++)
- {
-  if ( H5Tinsert(tid, field_names[i], field_offset[i], field_types[i] ) < 0 )
-   goto out;
- }
-
- return tid;
-
-out:
- return -1;
-}
-
-
-
-
-
-/*-------------------------------------------------------------------------
- * Function: H5LTrepack
- *
- * Purpose: Packs/Unpacks data from buffers. This function transfers data from a packed
- * data, src_buf, to a "natural byte aligned" (an n-byte item at an n-byte boundary)
- * data, dst_buf, and vice-versa.
- *
- * Return: Success: 0, Failure: -1
- *
- * Programmer: Pedro Vicente, pvn@ncsa.uiuc.edu
- *
- * Date: January 17, 2002
- *
- * Comments:
- *
- * Modifications:
- *
- *
- *-------------------------------------------------------------------------
- */
-
-herr_t H5LTrepack( hsize_t nfields,
-                   hsize_t nrecords,
-                   size_t src_size,
-                   const size_t *src_offset,
-                   const size_t *src_sizes,
-                   size_t dst_size,
-                   const size_t *dst_offset,
-                   const size_t *dst_sizes,
-                   unsigned char *src_buf,
-                   unsigned char *dst_buf )
-{
- hsize_t   i, j;
- /* size of each field of destination data counting with padding */
- size_t *size_pad = (size_t *)malloc((size_t)nfields * sizeof(size_t));
-
- /* Shut compiler */
- src_size=src_size;
- src_offset=src_offset;
-
- if ( size_pad == NULL )
-  goto out;
-
- for ( i= 0; i < nfields; i++)
- {
-
-  size_pad[i] = ( i == nfields-1 ? dst_size-dst_offset[i] : dst_offset[i+1]-dst_offset[i] );
-
- }
-
- /* Iterate tru the records */
- for ( i = 0; i < nrecords; i++)
- {
-  /* Iterate tru the members */
-  for ( j = 0; j < nfields; j++)
-  {
-
-   memcpy( dst_buf, src_buf, dst_sizes[j] );
-   dst_buf += size_pad[j];
-   src_buf += src_sizes[j];
-
-  }
-
- }
-
- if ( size_pad != NULL )
-  free( size_pad );
-
-return 0;
-
-out:
- return -1;
-
-}
 
 
 /*-------------------------------------------------------------------------
