@@ -1,4 +1,5 @@
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
+ * Copyright by The HDF Group.                                               *
  * Copyright by the Board of Trustees of the University of Illinois.         *
  * All rights reserved.                                                      *
  *                                                                           *
@@ -8,8 +9,8 @@
  * of the source code distribution tree; Copyright.html can be found at the  *
  * root level of an installed copy of the electronic HDF5 document set and   *
  * is linked from the top-level documents page.  It can also be found at     *
- * http://hdf.ncsa.uiuc.edu/HDF5/doc/Copyright.html.  If you do not have     *
- * access to either file, you may request a copy from hdfhelp@ncsa.uiuc.edu. *
+ * http://hdfgroup.org/HDF5/doc/Copyright.html.  If you do not have          *
+ * access to either file, you may request a copy from help@hdfgroup.org.     *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
 #ifndef _H5TB_H
@@ -42,7 +43,7 @@ extern "C" {
  *-------------------------------------------------------------------------
  */
 
-herr_t H5TBmake_table( const char *table_title,
+H5_HLDLL herr_t H5TBmake_table( const char *table_title,
                        hid_t loc_id,
                        const char *dset_name,
                        hsize_t nfields,
@@ -64,7 +65,7 @@ herr_t H5TBmake_table( const char *table_title,
  *-------------------------------------------------------------------------
  */
 
-herr_t H5TBappend_records( hid_t loc_id,
+H5_HLDLL herr_t H5TBappend_records( hid_t loc_id,
                            const char *dset_name,
                            hsize_t nrecords,
                            size_t type_size,
@@ -72,7 +73,7 @@ herr_t H5TBappend_records( hid_t loc_id,
                            const size_t *dst_sizes,
                            const void *data );
 
-herr_t H5TBwrite_records( hid_t loc_id,
+H5_HLDLL herr_t H5TBwrite_records( hid_t loc_id,
                           const char *dset_name,
                           hsize_t start,
                           hsize_t nrecords,
@@ -82,7 +83,7 @@ herr_t H5TBwrite_records( hid_t loc_id,
                           const void *data );
 
 
-herr_t H5TBwrite_fields_name( hid_t loc_id,
+H5_HLDLL herr_t H5TBwrite_fields_name( hid_t loc_id,
                               const char *dset_name,
                               const char *field_names,
                               hsize_t start,
@@ -92,7 +93,7 @@ herr_t H5TBwrite_fields_name( hid_t loc_id,
                               const size_t *dst_sizes,
                               const void *data );
 
-herr_t H5TBwrite_fields_index( hid_t loc_id,
+H5_HLDLL herr_t H5TBwrite_fields_index( hid_t loc_id,
                                const char *dset_name,
                                hsize_t nfields,
                                const int *field_index,
@@ -113,7 +114,7 @@ herr_t H5TBwrite_fields_index( hid_t loc_id,
 
 
 
-herr_t H5TBread_table( hid_t loc_id,
+H5_HLDLL herr_t H5TBread_table( hid_t loc_id,
                        const char *dset_name,
                        size_t dst_size,
                        const size_t *dst_offset,
@@ -121,7 +122,7 @@ herr_t H5TBread_table( hid_t loc_id,
                        void *dst_buf );
 
 
-herr_t H5TBread_fields_name( hid_t loc_id,
+H5_HLDLL herr_t H5TBread_fields_name( hid_t loc_id,
                              const char *dset_name,
                              const char *field_names,
                              hsize_t start,
@@ -131,7 +132,7 @@ herr_t H5TBread_fields_name( hid_t loc_id,
                              const size_t *dst_sizes,
                              void *data );
 
-herr_t H5TBread_fields_index( hid_t loc_id,
+H5_HLDLL herr_t H5TBread_fields_index( hid_t loc_id,
                               const char *dset_name,
                               hsize_t nfields,
                               const int *field_index,
@@ -143,7 +144,7 @@ herr_t H5TBread_fields_index( hid_t loc_id,
                               void *data );
 
 
-herr_t H5TBread_records( hid_t loc_id,
+H5_HLDLL herr_t H5TBread_records( hid_t loc_id,
                          const char *dset_name,
                          hsize_t start,
                          hsize_t nrecords,
@@ -160,12 +161,12 @@ herr_t H5TBread_records( hid_t loc_id,
  */
 
 
-herr_t H5TBget_table_info ( hid_t loc_id,
+H5_HLDLL herr_t H5TBget_table_info ( hid_t loc_id,
                             const char *dset_name,
                             hsize_t *nfields,
                             hsize_t *nrecords );
 
-herr_t H5TBget_field_info( hid_t loc_id,
+H5_HLDLL herr_t H5TBget_field_info( hid_t loc_id,
                            const char *dset_name,
                            char *field_names[],
                            size_t *field_sizes,
@@ -181,13 +182,13 @@ herr_t H5TBget_field_info( hid_t loc_id,
  */
 
 
-herr_t H5TBdelete_record( hid_t loc_id,
+H5_HLDLL herr_t H5TBdelete_record( hid_t loc_id,
                           const char *dset_name,
                           hsize_t start,
                           hsize_t nrecords );
 
 
-herr_t H5TBinsert_record( hid_t loc_id,
+H5_HLDLL herr_t H5TBinsert_record( hid_t loc_id,
                           const char *dset_name,
                           hsize_t start,
                           hsize_t nrecords,
@@ -196,20 +197,20 @@ herr_t H5TBinsert_record( hid_t loc_id,
                           const size_t *dst_sizes,
                           void *data );
 
-herr_t H5TBadd_records_from( hid_t loc_id,
+H5_HLDLL herr_t H5TBadd_records_from( hid_t loc_id,
                              const char *dset_name1,
                              hsize_t start1,
                              hsize_t nrecords,
                              const char *dset_name2,
                              hsize_t start2 );
 
-herr_t H5TBcombine_tables( hid_t loc_id1,
+H5_HLDLL herr_t H5TBcombine_tables( hid_t loc_id1,
                            const char *dset_name1,
                            hid_t loc_id2,
                            const char *dset_name2,
                            const char *dset_name3 );
 
-herr_t H5TBinsert_field( hid_t loc_id,
+H5_HLDLL herr_t H5TBinsert_field( hid_t loc_id,
                          const char *dset_name,
                          const char *field_name,
                          hid_t field_type,
@@ -217,7 +218,7 @@ herr_t H5TBinsert_field( hid_t loc_id,
                          const void *fill_data,
                          const void *data );
 
-herr_t H5TBdelete_field( hid_t loc_id,
+H5_HLDLL herr_t H5TBdelete_field( hid_t loc_id,
                          const char *dset_name,
                          const char *field_name );
 
@@ -229,10 +230,10 @@ herr_t H5TBdelete_field( hid_t loc_id,
  *-------------------------------------------------------------------------
  */
 
-herr_t H5TBAget_title( hid_t loc_id,
+H5_HLDLL herr_t H5TBAget_title( hid_t loc_id,
                        char *table_title );
 
-herr_t H5TBAget_fill( hid_t loc_id,
+H5_HLDLL herr_t H5TBAget_fill( hid_t loc_id,
                       const char *dset_name,
                       hid_t dset_id,
                       unsigned char *dst_buf );
