@@ -1,4 +1,5 @@
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
+ * Copyright by The HDF Group.                                               *
  * Copyright by the Board of Trustees of the University of Illinois.         *
  * All rights reserved.                                                      *
  *                                                                           *
@@ -8,8 +9,8 @@
  * of the source code distribution tree; Copyright.html can be found at the  *
  * root level of an installed copy of the electronic HDF5 document set and   *
  * is linked from the top-level documents page.  It can also be found at     *
- * http://hdf.ncsa.uiuc.edu/HDF5/doc/Copyright.html.  If you do not have     *
- * access to either file, you may request a copy from hdfhelp@ncsa.uiuc.edu. *
+ * http://hdfgroup.org/HDF5/doc/Copyright.html.  If you do not have          *
+ * access to either file, you may request a copy from help@hdfgroup.org.     *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
 #include "H5TA.h"
@@ -52,9 +53,11 @@
  *-------------------------------------------------------------------------
  */
 
-#define TITLE "Title"
-#define NFIELDS  (hsize_t)5
-#define NRECORDS (hsize_t)8
+#define TITLE           "Title"
+#define NFIELDS          5
+#define NRECORDS         8
+#define NRECORDS_ADD     3
+
 #define TESTING2(WHAT) {printf("%-70s", "Testing     " WHAT); fflush(stdout);}
 
 /*-------------------------------------------------------------------------
@@ -145,7 +148,12 @@ int test_table(hid_t fid, int write)
  hsize_t     position;
  char        tname[20];
 
+ /* indices */
+ int i, j;
+
  /* write, read, append, delete, insert some records and fields */
+ hsize_t FIELDS   = NFIELDS;
+ hsize_t RECORDS  = NRECORDS;
  hsize_t start;
  hsize_t wstart;
  hsize_t rstart;
@@ -159,7 +167,6 @@ int test_table(hid_t fid, int write)
  hsize_t drecords;
  hsize_t nfields;
  hsize_t rfields;
- hsize_t i, j;
  hsize_t start1;      /* record to start reading from 1st table */
  hsize_t start2;      /* record to start writing in 2nd table */
 
@@ -189,15 +196,10 @@ int test_table(hid_t fid, int write)
  float           pressure_out [NRECORDS];
  int             buf_new[NRECORDS] = { 0,1,2,3,4,5,6,7 };
  /* buffers for the fields "Latitude,Longitude"  */
- position_t      position_out[NRECORDS];
- position_t      position_in[NRECORDS] = { {0,0},
+ position_t      position_out[NRECORDS_ADD];
+ position_t      position_in[NRECORDS_ADD] = { {0,0},
  {10,10},
- {20,20},
- {30,30},
- {40,40},
- {50,50},
- {60,60},
- {70,70} };
+ {20,20}};
  /* buffers for the fields "Name,Pressure"  */
  namepressure_t   namepre_out[NRECORDS];
  namepressure_t   namepre_in[NRECORDS] =
@@ -351,7 +353,7 @@ int test_table(hid_t fid, int write)
  {
  TESTING2("making table");
 
- if (H5TBmake_table(TITLE,fid,"table1",NFIELDS,NRECORDS,type_size_mem,
+ if (H5TBmake_table(TITLE,fid,"table1",FIELDS,RECORDS,type_size_mem,
                     field_names,field_offset,field_type,
                     chunk_size,fill,compress,wbuf)<0)
                     goto out;
@@ -392,7 +394,7 @@ int test_table(hid_t fid, int write)
  TESTING2("writing records");
 
  /* create an empty table */
- if (H5TBmake_table(TITLE,fid,"table2",NFIELDS,NRECORDS,type_size_mem,
+ if (H5TBmake_table(TITLE,fid,"table2",FIELDS,RECORDS,type_size_mem,
                     field_names,field_offset,field_type,
                     chunk_size,fill,compress,0)<0)
                     goto out;
@@ -456,7 +458,7 @@ int test_table(hid_t fid, int write)
   goto out;
 
  /* compare */
- for( i=rstart; i<rrecords; i++)
+ for( i=(int)rstart; i<(int)rrecords; i++)
  {
   if (cmp_par(i,i,rbuf,wbuf)<0)
    goto out;
@@ -496,12 +498,12 @@ int test_table(hid_t fid, int write)
 
  /* compare */
  wrecords=8;
- for( i=rstart; i<wrecords; i++)
+ for( i=(int)rstart; i<(int)wrecords; i++)
  {
   if (cmp_par(i,i,rbuf,wbuf)<0)
    goto out;
  }
- for( i=wrecords, j=0; i<rrecords; i++,j++)
+ for( i=(int)wrecords, j=0; i<(int)rrecords; i++,j++)
  {
   if (cmp_par(i,j,rbuf,abuf)<0)
    goto out;
@@ -547,15 +549,15 @@ int test_table(hid_t fid, int write)
    if (cmp_par(i,i,rbuf,wbuf)<0)
     goto out;
   }
-  else if (i>=istart && i<istart+irecords)
+  else if (i>=(int)istart && i<(int)istart+(int)irecords)
   {
-   j=i-istart;
+   j=i-(int)istart;
    if (cmp_par(i,j,rbuf,ibuf)<0)
     goto out;
   }
-  else if (i>=istart+irecords && i<10)
+  else if (i>=(int)istart+(int)irecords && i<10)
   {
-   j=i-irecords;
+   j=i-(int)irecords;
    if (cmp_par(i,j,rbuf,wbuf)<0)
     goto out;
   }
@@ -588,10 +590,19 @@ int test_table(hid_t fid, int write)
  * data= 0 1 2 3 4 5 6 7
  *-------------------------------------------------------------------------
  */
- for( i=0; i<NRECORDS; i++)
-  wbufd[i] = wbuf[i];
 
- if (H5TBmake_table(TITLE,fid,"table3",NFIELDS,NRECORDS,type_size_mem,
+ for( i=0; i<NRECORDS; i++)
+ {
+  wbufd[i].lati = wbuf[i].lati;
+  wbufd[i].longi = wbuf[i].longi;
+  wbufd[i].pressure = wbuf[i].pressure;
+  wbufd[i].temperature = wbuf[i].temperature;
+  strcpy(wbufd[i].name, wbuf[i].name );
+  
+ }
+
+
+ if (H5TBmake_table(TITLE,fid,"table3",FIELDS,RECORDS,type_size_mem,
                     field_names,field_offset,field_type,
                     chunk_size,fill,compress,wbufd)<0)
                     goto out;
@@ -750,11 +761,11 @@ int test_table(hid_t fid, int write)
  TESTING2("adding records");
 
  /* create 2 tables */
- if (H5TBmake_table(TITLE,fid,"table4",NFIELDS,NRECORDS,type_size_mem,
+ if (H5TBmake_table(TITLE,fid,"table4",FIELDS,RECORDS,type_size_mem,
                     field_names,field_offset,field_type,
                     chunk_size,fill,compress,wbuf)<0)
                     goto out;
- if (H5TBmake_table(TITLE,fid,"table5",NFIELDS,NRECORDS,type_size_mem,
+ if (H5TBmake_table(TITLE,fid,"table5",FIELDS,RECORDS,type_size_mem,
                     field_names,field_offset,field_type,
                     chunk_size,fill,compress,wbuf)<0)
                     goto out;
@@ -778,15 +789,15 @@ int test_table(hid_t fid, int write)
    if (cmp_par(i,i,rbuf,wbuf)<0)
     goto out;
   }
-  else if ( i < start2+nrecords )
+  else if ( i < (int)start2+(int)nrecords )
   {
-   j = i-start1;
+   j = i-(int)start1;
    if (cmp_par(i,j,rbuf,wbuf)<0)
     goto out;
   }
   else
   {
-   j = i-nrecords;
+   j = i-(int)nrecords;
    if (cmp_par(i,j,rbuf,wbuf)<0)
     goto out;
   }
@@ -810,11 +821,11 @@ int test_table(hid_t fid, int write)
  TESTING2("combining tables");
 
  /* create 2 tables */
- if (H5TBmake_table(TITLE,fid,"table6",NFIELDS,NRECORDS,type_size_mem,
+ if (H5TBmake_table(TITLE,fid,"table6",FIELDS,RECORDS,type_size_mem,
                     field_names,field_offset,field_type,
                     chunk_size,fill,compress,wbuf)<0)
                     goto out;
- if (H5TBmake_table(TITLE,fid,"table7",NFIELDS,NRECORDS,type_size_mem,
+ if (H5TBmake_table(TITLE,fid,"table7",FIELDS,RECORDS,type_size_mem,
                     field_names,field_offset,field_type,
                     chunk_size,fill,compress,wbuf)<0)
                     goto out;
@@ -852,11 +863,11 @@ int test_table(hid_t fid, int write)
  fid2 = H5Fcreate("combine_tables2.h5",H5F_ACC_TRUNC,H5P_DEFAULT,H5P_DEFAULT);
 
  /* create 2 tables, one in each file */
- if (H5TBmake_table(TITLE,fid1,"table1",NFIELDS,NRECORDS,type_size_mem,
+ if (H5TBmake_table(TITLE,fid1,"table1",FIELDS,RECORDS,type_size_mem,
                     field_names,field_offset,field_type,
                     chunk_size,fill,compress,wbuf)<0)
                     goto out;
- if (H5TBmake_table(TITLE,fid2,"table2",NFIELDS,NRECORDS,type_size_mem,
+ if (H5TBmake_table(TITLE,fid2,"table2",FIELDS,RECORDS,type_size_mem,
                     field_names,field_offset,field_type,
                     chunk_size,fill,compress,wbuf)<0)
                     goto out;
@@ -905,14 +916,14 @@ int test_table(hid_t fid, int write)
  TESTING2("writing fields by name");
 
  /* make an empty table with fill values */
- if (H5TBmake_table(TITLE,fid,"table9",NFIELDS,NRECORDS,type_size_mem,
+ if (H5TBmake_table(TITLE,fid,"table9",FIELDS,RECORDS,type_size_mem,
                     field_names,field_offset,field_type,
                     chunk_size,fill1,compress,0)<0)
                     goto out;
 
  /* write the pressure field starting at record 2 */
  start    = 2;
- nrecords = 3;
+ nrecords = NRECORDS_ADD;
  if (H5TBwrite_fields_name(fid,"table9","Pressure",start,nrecords,sizeof(float),
   0,field_sizes_pre,pressure_in)<0)
   goto out;
@@ -930,23 +941,29 @@ int test_table(hid_t fid, int write)
  if (H5TBread_table(fid,"table9",type_size_mem,field_offset,field_size,rbuf)<0)
   goto out;
 
- /* compare the read values with the initial values */
- for( i = 0; i < NRECORDS; i++ )
- {
-  if ( i >= 2 && i <= 4 )
   {
-    if ( rbuf[i].lati        != position_in[i].lati ||
-         rbuf[i].longi       != position_in[i].longi ||
-         rbuf[i].pressure    != pressure_in[i] )
+   
+   
+   /* compare the read values with the initial values */
+   for( i = 0; i < NRECORDS; i++ )
+   {
+    if ( i >= 2 && i <= 4 )
     {
-     fprintf(stderr,"%ld %f %d\n",
-      rbuf[i].longi,rbuf[i].pressure,rbuf[i].lati);
-     fprintf(stderr,"%ld %f %d\n",
-      position_in[i].longi,pressure_in[i],position_in[i].lati);
+     if ( rbuf[i].lati        != position_in[i-NRECORDS_ADD+1].lati ||
+      rbuf[i].longi       != position_in[i-NRECORDS_ADD+1].longi ||
+      rbuf[i].pressure    != pressure_in[i-NRECORDS_ADD+1] )
+     {
+      fprintf(stderr,"%ld %f %d\n",
+       rbuf[i].longi,rbuf[i].pressure,rbuf[i].lati);
+      fprintf(stderr,"%ld %f %d\n",
+       position_in[i].longi,pressure_in[i],position_in[i].lati);
       goto out;
+     }
     }
+   }
   }
- }
+
+
 
  PASSED();
  } /*write*/
@@ -967,7 +984,7 @@ int test_table(hid_t fid, int write)
  */
  if (write)
  {
-  if (H5TBmake_table(TITLE,fid,"table10",NFIELDS,NRECORDS,type_size_mem,
+  if (H5TBmake_table(TITLE,fid,"table10",FIELDS,RECORDS,type_size_mem,
    field_names,field_offset,field_type,
    chunk_size,fill1,compress,0)<0)
    goto out;
@@ -987,6 +1004,7 @@ int test_table(hid_t fid, int write)
   sizeof(float),0,field_sizes_pre,pressure_out)<0)
   goto out;
 
+
  /* Compare the extracted table with the initial values */
  for( i = 0; i < NRECORDS; i++ )
  {
@@ -1003,7 +1021,7 @@ int test_table(hid_t fid, int write)
  {
   /* Write the new longitude and latitude information to all the records */
   start    = 0;
-  nrecords = NRECORDS;
+  nrecords = NRECORDS_ADD;
   if ( H5TBwrite_fields_name(fid,"table10", "Latitude,Longitude", start, nrecords,
    sizeof( position_t ), field_offset_pos, field_sizes_pos, position_in  ) < 0 )
    goto out;
@@ -1011,13 +1029,14 @@ int test_table(hid_t fid, int write)
 
  /* Read the "Latitude,Longitude" fields */
  start    = 0;
- nrecords = NRECORDS;
+ nrecords = NRECORDS_ADD;
  if ( H5TBread_fields_name( fid, "table10", "Latitude,Longitude",
   start, nrecords, sizeof(position_t), field_offset_pos, field_sizes_pos, position_out ) < 0 )
   goto out;
 
+
  /* Compare the extracted table with the initial values */
- for( i = 0; i < NRECORDS; i++ )
+ for( i = 0; i < NRECORDS_ADD; i++ )
  {
   if ( position_out[i].lati  != position_in[i].lati ||
    position_out[i].longi != position_in[i].longi )
@@ -1047,6 +1066,7 @@ int test_table(hid_t fid, int write)
    namepre_out ) < 0 )
   goto out;
 
+
  /* Compare the extracted table with the initial values */
  for( i = 0; i < NRECORDS; i++ )
  {
@@ -1055,6 +1075,7 @@ int test_table(hid_t fid, int write)
    goto out;
   }
  }
+
  /* reset buffer */
  for( i = 0; i < NRECORDS; i++ )
  {
@@ -1073,14 +1094,19 @@ int test_table(hid_t fid, int write)
    field_sizes_namepre, namepre_out ) < 0 )
   goto out;
 
+
  /* Compare the extracted table with the initial values */
  for( i = 0; i < 3; i++ )
  {
-  if ( ( strcmp( namepre_out[i].name,  namepre_in[start+i].name ) != 0 ) ||
-         namepre_out[i].pressure != namepre_in[start+i].pressure ) {
+  int iistart = (int) start;
+  if ( ( strcmp( namepre_out[i].name,  namepre_in[iistart+i].name ) != 0 ) ||
+         namepre_out[i].pressure != namepre_in[iistart+i].pressure ) {
    goto out;
   }
  }
+
+ 
+
  PASSED();
 
 /*-------------------------------------------------------------------------
@@ -1096,7 +1122,7 @@ int test_table(hid_t fid, int write)
  TESTING2("writing fields by index");
 
  /* make an empty table */
- if (H5TBmake_table(TITLE,fid,"table11",NFIELDS,NRECORDS,type_size_mem,
+ if (H5TBmake_table(TITLE,fid,"table11",FIELDS,RECORDS,type_size_mem,
                     field_names,field_offset,field_type,
                     chunk_size,fill,compress,NULL)<0)
                     goto out;
@@ -1104,7 +1130,7 @@ int test_table(hid_t fid, int write)
  /* write the pressure field starting at record 2 */
  nfields  = 1;
  start    = 2;
- nrecords = 3;
+ nrecords = NRECORDS_ADD;
  if ( H5TBwrite_fields_index(fid, "table11", nfields, field_index_pre, start, nrecords,
    sizeof( float ), 0, field_sizes_pre, pressure_in  ) < 0 )
   goto out;
@@ -1113,7 +1139,7 @@ int test_table(hid_t fid, int write)
  /* write the new longitude and latitude information starting at record 2  */
  nfields  = 2;
  start    = 2;
- nrecords = 3;
+ nrecords = NRECORDS_ADD;
  if ( H5TBwrite_fields_index(fid, "table11", nfields, field_index_pos, start, nrecords,
    sizeof( position_t ), field_offset_pos, field_sizes_pos, position_in  ) < 0 )
   goto out;
@@ -1131,9 +1157,9 @@ int test_table(hid_t fid, int write)
  {
   if ( i >= 2 && i <= 4 )
   {
-    if ( rbuf[i].lati        != position_in[i].lati ||
-         rbuf[i].longi       != position_in[i].longi ||
-         rbuf[i].pressure    != pressure_in[i] )
+    if ( rbuf[i].lati        != position_in[i-NRECORDS_ADD+1].lati ||
+         rbuf[i].longi       != position_in[i-NRECORDS_ADD+1].longi ||
+         rbuf[i].pressure    != pressure_in[i-NRECORDS_ADD+1] )
    goto out;
   }
  }
@@ -1156,7 +1182,7 @@ int test_table(hid_t fid, int write)
  if (write)
  {
  /* make an empty table */
- if (H5TBmake_table(TITLE,fid,"table12",NFIELDS,NRECORDS,type_size_mem,
+ if (H5TBmake_table(TITLE,fid,"table12",FIELDS,RECORDS,type_size_mem,
                     field_names,field_offset,field_type,
                     chunk_size,fill,compress,NULL)<0)
                     goto out;
@@ -1209,13 +1235,13 @@ int test_table(hid_t fid, int write)
  /* read the "Latitude,Longitude" fields */
  nfields = 2;
  start    = 0;
- nrecords = NRECORDS;
+ nrecords = NRECORDS_ADD;
  if ( H5TBread_fields_index(fid, "table12", nfields, field_index_pos,
    start, nrecords, sizeof(position_t), field_offset_pos, field_sizes_pos, position_out ) < 0 )
   goto out;
 
  /* compare the extracted table with the initial values */
- for( i = 0; i < NRECORDS; i++ )
+ for( i = 0; i < NRECORDS_ADD; i++ )
  {
   if ( position_out[i].lati  != position_in[i].lati ||
        position_out[i].longi != position_in[i].longi ) {
@@ -1281,8 +1307,9 @@ int test_table(hid_t fid, int write)
  /* compare the extracted table with the initial values */
  for( i = 0; i < 3; i++ )
  {
-  if ( ( strcmp( namepre_out[i].name,  wbuf[start+i].name ) != 0 ) ||
-   namepre_out[i].pressure != wbuf[start+i].pressure ) {
+  int iistart = (int) start;
+  if ( ( strcmp( namepre_out[i].name,  wbuf[iistart+i].name ) != 0 ) ||
+   namepre_out[i].pressure != wbuf[iistart+i].pressure ) {
    goto out;
   }
  }
@@ -1304,7 +1331,7 @@ int test_table(hid_t fid, int write)
  TESTING2("inserting fields");
 
  /* make a table */
- if (H5TBmake_table(TITLE,fid,"table13",NFIELDS,NRECORDS,type_size_mem,
+ if (H5TBmake_table(TITLE,fid,"table13",FIELDS,RECORDS,type_size_mem,
                     field_names,field_offset,field_type,
                     chunk_size,fill1,compress,wbuf)<0)
                     goto out;
@@ -1348,7 +1375,7 @@ int test_table(hid_t fid, int write)
  TESTING2("deleting fields");
 
   /* make a table */
- if (H5TBmake_table(TITLE,fid,"table14",NFIELDS,NRECORDS,type_size_mem,
+ if (H5TBmake_table(TITLE,fid,"table14",FIELDS,RECORDS,type_size_mem,
                     field_names,field_offset,field_type,
                     chunk_size,fill,compress,wbuf)<0)
                     goto out;
