@@ -1,4 +1,5 @@
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
+ * Copyright by The HDF Group.                                               *
  * Copyright by the Board of Trustees of the University of Illinois.         *
  * All rights reserved.                                                      *
  *                                                                           *
@@ -8,8 +9,8 @@
  * of the source code distribution tree; Copyright.html can be found at the  *
  * root level of an installed copy of the electronic HDF5 document set and   *
  * is linked from the top-level documents page.  It can also be found at     *
- * http://hdf.ncsa.uiuc.edu/HDF5/doc/Copyright.html.  If you do not have     *
- * access to either file, you may request a copy from hdfhelp@ncsa.uiuc.edu. *
+ * http://hdfgroup.org/HDF5/doc/Copyright.html.  If you do not have          *
+ * access to either file, you may request a copy from help@hdfgroup.org.     *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
 #define H5F_PACKAGE		/*suppress error about including H5Fpkg	  */
@@ -28,6 +29,9 @@
 #include "H5MMprivate.h"	/* Memory management			*/
 
 /* PRIVATE PROTOTYPES */
+static herr_t H5F_mount(H5G_entry_t *loc, const char *name, H5F_t *child,
+    hid_t plist_id, hid_t dxpl_id);
+static herr_t H5F_unmount(H5G_entry_t *loc, const char *name, hid_t dxpl_id);
 
 
 /*--------------------------------------------------------------------------
@@ -62,8 +66,6 @@ H5F_init_mount_interface(void)
  * Programmer:	Quincey Koziol
  *              Saturday, July  2, 2005
  *
- * Modifications:
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -108,14 +110,6 @@ done:
  * Programmer:	Robb Matzke
  *              Tuesday, October  6, 1998
  *
- * Modifications:
- *
- * 	Robb Matzke, 1998-10-14
- *	The reference count for the mounted H5F_t is incremented.
- *
- *      Pedro Vicente, <pvn@ncsa.uiuc.edu> 22 Aug 2002
- *      Added `id to name' support.
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -123,42 +117,48 @@ H5F_mount(H5G_entry_t *loc, const char *name, H5F_t *child,
 	  hid_t UNUSED plist_id, hid_t dxpl_id)
 {
     H5G_t	*mount_point = NULL;	/*mount point group		*/
-    H5G_entry_t	*mp_ent = NULL;		/*mount point symbol table entry*/
     H5F_t	*ancestor = NULL;	/*ancestor files		*/
     H5F_t	*parent = NULL;		/*file containing mount point	*/
     unsigned	lt, rt, md;		/*binary search indices		*/
     int		cmp;			/*binary search comparison value*/
-    H5G_entry_t	*ent = NULL;		/*temporary symbol table entry	*/
-    H5G_entry_t  mp_open_ent;     /* entry of moint point to be opened */
-    H5RS_str_t  *name_r;                /* Ref-counted version of name */
+    H5G_entry_t	*mp_ent = NULL;		/*mount point symbol table entry*/
+    H5G_entry_t mp_open_ent;     	/*entry of moint point to be opened */
+    H5G_entry_t *root_ent;              /* Symbol table for root of file to mount */
     herr_t	ret_value = SUCCEED;	/*return value			*/
 
     FUNC_ENTER_NOAPI_NOINIT(H5F_mount)
 
-    assert(loc);
-    assert(name && *name);
-    assert(child);
-    assert(TRUE==H5P_isa_class(plist_id,H5P_MOUNT));
+    HDassert(loc);
+    HDassert(name && *name);
+    HDassert(child);
+    HDassert(TRUE == H5P_isa_class(plist_id,H5P_MOUNT));
 
     /*
      * Check that the child isn't mounted, that the mount point exists, that
      * the parent & child files have the same file close degree, and
      * that the mount wouldn't introduce a cycle in the mount tree.
      */
-    if (child->mtab.parent)
+    if(child->mtab.parent)
         HGOTO_ERROR(H5E_FILE, H5E_MOUNT, FAIL, "file is already mounted")
-    if (H5G_find(loc, name, &mp_open_ent/*out*/, H5AC_dxpl_id) < 0)
+    if(H5G_find(loc, name, &mp_open_ent/*out*/, H5AC_dxpl_id) < 0)
         HGOTO_ERROR(H5E_SYM, H5E_NOTFOUND, FAIL, "group not found")
-    if (NULL==(mount_point=H5G_open(&mp_open_ent, dxpl_id)))
+    if(NULL == (mount_point = H5G_open(&mp_open_ent, dxpl_id)))
         HGOTO_ERROR(H5E_FILE, H5E_MOUNT, FAIL, "mount point not found")
 
+    /* Retrieve information from the mount point group */
+    /* (Some of which we had before but was reset in mp_loc when the group
+     *  "took over" the group location - QAK)
+     */
     parent = H5G_fileof(mount_point);
+    HDassert(parent);
     mp_ent = H5G_entof(mount_point);
-    for (ancestor=parent; ancestor; ancestor=ancestor->mtab.parent) {
-	if (ancestor==child)
+    HDassert(mp_ent);
+    for(ancestor = parent; ancestor; ancestor = ancestor->mtab.parent) {
+	if(ancestor == child)
 	    HGOTO_ERROR(H5E_FILE, H5E_MOUNT, FAIL, "mount would introduce a cycle")
-    }
+    } /* end for */
 
+    /* Make certain that the parent & child files have the same "file close degree" */
     if(parent->shared->fc_degree != child->shared->fc_degree)
         HGOTO_ERROR(H5E_FILE, H5E_MOUNT, FAIL, "mounted file has different file close degree than parent")
 
@@ -168,62 +168,63 @@ H5F_mount(H5G_entry_t *loc, const char *name, H5F_t *child,
      * `md' will be the index where the child should be inserted.
      */
     lt = md = 0;
-    rt=parent->mtab.nmounts;
+    rt = parent->mtab.nmounts;
     cmp = -1;
-    while (lt<rt && cmp) {
-	md = (lt+rt)/2;
+    while(lt < rt && cmp) {
+        H5G_entry_t	*ent;		/*temporary symbol table entry	*/
+
+	md = (lt + rt) / 2;
 	ent = H5G_entof(parent->mtab.child[md].group);
 	cmp = H5F_addr_cmp(mp_ent->header, ent->header);
-	if (cmp<0) {
+	if(cmp < 0)
 	    rt = md;
-	} else if (cmp>0) {
-	    lt = md+1;
-	}
-    }
-    if (cmp>0)
+	else if(cmp > 0)
+	    lt = md + 1;
+    } /* end while */
+    if(cmp > 0)
         md++;
-    if (!cmp)
+    if(!cmp)
 	HGOTO_ERROR(H5E_FILE, H5E_MOUNT, FAIL, "mount point is already in use")
 
     /* Make room in the table */
-    if (parent->mtab.nmounts>=parent->mtab.nalloc) {
+    if(parent->mtab.nmounts>=parent->mtab.nalloc) {
 	unsigned n = MAX(16, 2*parent->mtab.nalloc);
 	H5F_mount_t *x = H5MM_realloc(parent->mtab.child,
-				      n*sizeof(parent->mtab.child[0]));
+				      n * sizeof(parent->mtab.child[0]));
 	if (!x)
 	    HGOTO_ERROR(H5E_RESOURCE, H5E_NOSPACE, FAIL, "memory allocation failed for mount table")
 	parent->mtab.child = x;
 	parent->mtab.nalloc = n;
-    }
+    } /* end if */
 
     /* Insert into table */
-    HDmemmove(parent->mtab.child+md+1, parent->mtab.child+md,
-        (parent->mtab.nmounts-md)*sizeof(parent->mtab.child[0]));
+    HDmemmove(parent->mtab.child + md + 1, parent->mtab.child + md,
+            (parent->mtab.nmounts-md) * sizeof(parent->mtab.child[0]));
     parent->mtab.nmounts++;
     parent->mtab.child[md].group = mount_point;
     parent->mtab.child[md].file = child;
     child->mtab.parent = parent;
 
     /* Set the group's mountpoint flag */
-    if(H5G_mount(parent->mtab.child[md].group)<0)
+    if(H5G_mount(parent->mtab.child[md].group) < 0)
         HGOTO_ERROR(H5E_FILE, H5E_CANTCLOSEOBJ, FAIL, "unable to set group mounted flag")
 
+    /* Get the group location for the root group in the file to unmount */
+    if(NULL == (root_ent = H5G_entof(child->shared->root_grp)))
+        HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, FAIL, "unable to get entry for root group")
+
     /* Search the open IDs and replace names for mount operation */
     /* We pass H5G_UNKNOWN as object type; search all IDs */
-    name_r=H5RS_wrap(name);
-    assert(name_r);
-    if (H5G_replace_name( H5G_UNKNOWN, loc, name_r, NULL, NULL, NULL, OP_MOUNT )<0)
+    if(H5G_name_replace(H5G_UNKNOWN, mp_ent, NULL, root_ent, H5G_NAME_MOUNT) < 0)
 	HGOTO_ERROR(H5E_FILE, H5E_MOUNT, FAIL, "unable to replace name")
-    if(H5RS_decr(name_r)<0)
-	HGOTO_ERROR(H5E_FILE, H5E_CANTDEC, FAIL, "unable to decrement name string")
 
 done:
-    if (ret_value<0 && mount_point)
-	if(H5G_close(mount_point)<0)
+    if(ret_value < 0 && mount_point)
+	if(H5G_close(mount_point) < 0)
             HDONE_ERROR(H5E_FILE, H5E_CANTCLOSEOBJ, FAIL, "unable to close mounted group")
 
     FUNC_LEAVE_NOAPI(ret_value)
-}
+} /* end H5F_mount() */
 
 
 /*-------------------------------------------------------------------------
@@ -242,14 +243,6 @@ done:
  * Programmer:	Robb Matzke
  *              Tuesday, October  6, 1998
  *
- * Modifications:
- *
- *      Robb Matzke, 1998-10-14
- *      The ref count for the child is decremented by calling H5F_close().
- *
- *      Pedro Vicente, <pvn@ncsa.uiuc.edu> 22 Aug 2002
- *      Added `id to name' support.
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -257,35 +250,35 @@ H5F_unmount(H5G_entry_t *loc, const char *name, hid_t dxpl_id)
 {
     H5G_t	*mounted = NULL;	/*mount point group		*/
     H5G_t	*child_group = NULL;	/* Child's group in parent mtab	*/
-    H5F_t	*child_file = NULL;	/* Child's file in parent mtab	*/
-    H5G_entry_t	*mnt_ent = NULL;	/*mounted symbol table entry	*/
     H5F_t	*child = NULL;		/*mounted file			*/
     H5F_t	*parent = NULL;		/*file where mounted		*/
+    H5G_entry_t	*mnt_ent = NULL;	/*mounted symbol table entry	*/
     H5G_entry_t	*ent = NULL;		/*temporary symbol table entry	*/
     H5G_entry_t mnt_open_ent;           /* entry used to open mount point*/
+    H5G_entry_t *root_ent;              /* Symbol table for root of file to mount */
     int         child_idx;              /* Index of child in parent's mtab */
     herr_t	ret_value = SUCCEED;	/*return value			*/
 
     FUNC_ENTER_NOAPI_NOINIT(H5F_unmount)
 
-    assert(loc);
-    assert(name && *name);
+    HDassert(loc);
+    HDassert(name && *name);
 
     /*
      * Get the mount point, or more precisely the root of the mounted file.
      * If we get the root group and the file has a parent in the mount tree,
      * then we must have found the mount point.
      */
-    if (H5G_find(loc, name, &mnt_open_ent/*out*/, H5AC_dxpl_id) < 0)
+    if(H5G_find(loc, name, &mnt_open_ent/*out*/, H5AC_dxpl_id) < 0)
         HGOTO_ERROR(H5E_SYM, H5E_NOTFOUND, FAIL, "group not found")
-    if (NULL==(mounted=H5G_open(&mnt_open_ent, dxpl_id)))
+    if(NULL == (mounted = H5G_open(&mnt_open_ent, dxpl_id)))
         HGOTO_ERROR(H5E_FILE, H5E_MOUNT, FAIL, "mount point not found")
     child = H5G_fileof(mounted);
     mnt_ent = H5G_entof(mounted);
     ent = H5G_entof(child->shared->root_grp);
     child_idx = -1;
 
-    if (child->mtab.parent && H5F_addr_eq(mnt_ent->header, ent->header)) {
+    if(child->mtab.parent && H5F_addr_eq(mnt_ent->header, ent->header)) {
         unsigned	u;		/*counters			*/
 
 	/*
@@ -293,15 +286,15 @@ H5F_unmount(H5G_entry_t *loc, const char *name, hid_t dxpl_id)
 	 * lookup in the parent's mount table to find the correct entry.
 	 */
 	parent = child->mtab.parent;
-	for (u=0; u<parent->mtab.nmounts; u++) {
-	    if (parent->mtab.child[u].file==child) {
+	for(u = 0; u < parent->mtab.nmounts; u++) {
+	    if(parent->mtab.child[u].file == child) {
                 /* Found the correct index */
                 child_idx = u;
                 break;
-	    }
-	}
+	    } /* end if */
+	} /* end for */
     } else {
-        unsigned lt, rt, md=0;	        /*binary search indices		*/
+        unsigned lt, rt, md = 0;        /*binary search indices		*/
         int 	cmp;		        /*binary search comparison value*/
 
 	/*
@@ -312,57 +305,59 @@ H5F_unmount(H5G_entry_t *loc, const char *name, hid_t dxpl_id)
 	lt = 0;
         rt = parent->mtab.nmounts;
 	cmp = -1;
-	while (lt<rt && cmp) {
-	    md = (lt+rt)/2;
+	while(lt < rt && cmp) {
+	    md = (lt + rt) / 2;
 	    ent = H5G_entof(parent->mtab.child[md].group);
 	    cmp = H5F_addr_cmp(mnt_ent->header, ent->header);
-	    if (cmp<0) {
+	    if (cmp<0)
 		rt = md;
-	    } else {
-		lt = md+1;
-	    }
-	}
-	if (cmp)
+	    else
+		lt = md + 1;
+	} /* end while */
+	if(cmp)
 	    HGOTO_ERROR(H5E_FILE, H5E_MOUNT, FAIL, "not a mount point")
 
-        /* Found the correct index */
+        /* Found the correct index, set the info about the child */
         child_idx = md;
         mnt_ent = ent;
-    }
-
+        child = parent->mtab.child[child_idx].file;
+    } /* end else */
     HDassert(child_idx >= 0);
 
-    /* Search the open IDs replace names to reflect unmount operation */
-    if (H5G_replace_name(H5G_UNKNOWN, mnt_ent, mnt_ent->user_path_r, NULL, NULL, NULL, OP_UNMOUNT )<0)
-        HGOTO_ERROR(H5E_SYM, H5E_CANTINIT, FAIL, "unable to replace name ")
-
     /* Save the information about the child from the mount table */
     child_group = parent->mtab.child[child_idx].group;
-    child_file = parent->mtab.child[child_idx].file;
+
+    /* Get the group location for the root group in the file to unmount */
+    if(NULL == (root_ent = H5G_entof(child->shared->root_grp)))
+        HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, FAIL, "unable to get entry for root group")
+
+    /* Search the open IDs replace names to reflect unmount operation */
+    if(H5G_name_replace(H5G_UNKNOWN, mnt_ent, NULL, root_ent, H5G_NAME_UNMOUNT )<0)
+        HGOTO_ERROR(H5E_SYM, H5E_CANTINIT, FAIL, "unable to replace name")
 
     /* Eliminate the mount point from the table */
-    HDmemmove(parent->mtab.child+child_idx, parent->mtab.child+child_idx+1,
-        (parent->mtab.nmounts-child_idx)*sizeof(parent->mtab.child[0]));
+    HDmemmove(parent->mtab.child + child_idx, parent->mtab.child + child_idx + 1,
+            (parent->mtab.nmounts-child_idx) * sizeof(parent->mtab.child[0]));
     parent->mtab.nmounts -= 1;
 
     /* Unmount the child file from the parent file */
-    if(H5G_unmount(child_group)<0)
+    if(H5G_unmount(child_group) < 0)
         HGOTO_ERROR(H5E_FILE, H5E_CANTCLOSEOBJ, FAIL, "unable to reset group mounted flag")
-    if(H5G_close(child_group)<0)
+    if(H5G_close(child_group) < 0)
         HGOTO_ERROR(H5E_FILE, H5E_CANTCLOSEOBJ, FAIL, "unable to close unmounted group")
 
     /* Detach child file from parent & see if it should close */
-    child_file->mtab.parent = NULL;
-    if(H5F_try_close(child_file)<0)
+    child->mtab.parent = NULL;
+    if(H5F_try_close(child) < 0)
         HGOTO_ERROR(H5E_FILE, H5E_CANTCLOSEFILE, FAIL, "unable to close unmounted file")
 
 done:
-    if (mounted)
-        if(H5G_close(mounted)<0 && ret_value>=0)
+    if(mounted)
+        if(H5G_close(mounted) < 0 && ret_value >= 0)
 	    HDONE_ERROR(H5E_FILE, H5E_CANTCLOSEOBJ, FAIL, "can't close group")
 
     FUNC_LEAVE_NOAPI(ret_value)
-}
+} /* end H5F_unmount() */
 
 
 /*-------------------------------------------------------------------------
@@ -420,17 +415,17 @@ H5F_mountpoint(H5G_entry_t *find/*in,out*/)
 	}
 
 	/* Copy root info over to ENT */
-	if (0==cmp) {
+	if(0 == cmp) {
             /* Get the entry for the root group in the child's file */
 	    ent = H5G_entof(parent->mtab.child[md].file->shared->root_grp);
 
-            /* Don't lose the user path of the group when we copy the root group's entry */
-            if(H5G_ent_copy(find,ent,H5G_COPY_LIMITED)<0)
+            /* Don't lose the paths of the group when we copy the root group's entry */
+            if(H5G_ent_copy(find, ent, H5_COPY_LIMITED) < 0)
                 HGOTO_ERROR(H5E_FILE, H5E_CANTCOPY, FAIL, "unable to copy group entry")
 
             /* Switch to child's file */
 	    parent = ent->file;
-	}
+	} /* end if */
     } while (!cmp);
 
 done:
@@ -444,30 +439,27 @@ done:
  * Purpose:	Check if a file has mounted files within it.
  *
  * Return:	Success:	TRUE/FALSE
- *		Failure:	Negative
+ *		Failure:	(can't happen)
  *
  * Programmer:	Quincey Koziol
  *              Thursday, January  2, 2002
  *
- * Modifications:
- *
  *-------------------------------------------------------------------------
  */
-htri_t
+hbool_t
 H5F_has_mount(const H5F_t *file)
 {
-    htri_t ret_value;   /* Return value */
+    hbool_t ret_value;   /* Return value */
 
-    FUNC_ENTER_NOAPI(H5F_has_mount, FAIL)
+    FUNC_ENTER_NOAPI_NOINIT_NOFUNC(H5F_has_mount)
 
-    assert(file);
+    HDassert(file);
 
-    if(file->mtab.nmounts>0)
-        ret_value=TRUE;
+    if(file->mtab.nmounts > 0)
+        ret_value = TRUE;
     else
-        ret_value=FALSE;
+        ret_value = FALSE;
 
-done:
     FUNC_LEAVE_NOAPI(ret_value)
 } /* end H5F_has_mount() */
 
@@ -478,30 +470,27 @@ done:
  * Purpose:	Check if a file is mounted within another file.
  *
  * Return:	Success:	TRUE/FALSE
- *		Failure:	Negative
+ *		Failure:	(can't happen)
  *
  * Programmer:	Quincey Koziol
  *              Thursday, January  2, 2002
  *
- * Modifications:
- *
  *-------------------------------------------------------------------------
  */
-htri_t
+hbool_t
 H5F_is_mount(const H5F_t *file)
 {
-    htri_t ret_value;   /* Return value */
+    hbool_t ret_value;   /* Return value */
 
-    FUNC_ENTER_NOAPI(H5F_is_mount, FAIL)
+    FUNC_ENTER_NOAPI_NOINIT_NOFUNC(H5F_is_mount)
 
-    assert(file);
+    HDassert(file);
 
-    if(file->mtab.parent!=NULL)
-        ret_value=TRUE;
+    if(file->mtab.parent != NULL)
+        ret_value = TRUE;
     else
-        ret_value=FALSE;
+        ret_value = FALSE;
 
-done:
     FUNC_LEAVE_NOAPI(ret_value)
 } /* end H5F_is_mount() */
 
@@ -517,26 +506,24 @@ done:
  * Programmer:	Robb Matzke
  *              Tuesday, October  6, 1998
  *
- * Modifications:
- *
  *-------------------------------------------------------------------------
  */
 herr_t
 H5Fmount(hid_t loc_id, const char *name, hid_t child_id, hid_t plist_id)
 {
     H5G_entry_t		*loc = NULL;
-    H5F_t		*child = NULL;
+    H5F_t	*child = NULL;
     herr_t      ret_value=SUCCEED;       /* Return value */
 
     FUNC_ENTER_API(H5Fmount, FAIL)
     H5TRACE4("e","isii",loc_id,name,child_id,plist_id);
 
     /* Check arguments */
-    if (NULL==(loc=H5G_loc(loc_id)))
+    if(NULL == (loc = H5G_loc(loc_id)))
 	HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, FAIL, "not a location")
-    if (!name || !*name)
+    if(!name || !*name)
 	HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, FAIL, "no name")
-    if (NULL==(child=H5I_object_verify(child_id,H5I_FILE)))
+    if(NULL == (child = H5I_object_verify(child_id,H5I_FILE)))
 	HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, FAIL, "not a file")
     if(H5P_DEFAULT == plist_id)
         plist_id = H5P_MOUNT_DEFAULT;
@@ -545,12 +532,12 @@ H5Fmount(hid_t loc_id, const char *name, hid_t child_id, hid_t plist_id)
             HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, FAIL, "not property list")
 
     /* Do the mount */
-    if (H5F_mount(loc, name, child, plist_id, H5AC_dxpl_id)<0)
+    if(H5F_mount(loc, name, child, plist_id, H5AC_dxpl_id) < 0)
 	HGOTO_ERROR(H5E_FILE, H5E_MOUNT, FAIL, "unable to mount file")
 
 done:
     FUNC_LEAVE_API(ret_value)
-}
+} /* end H5Fmount() */
 
 
 /*-------------------------------------------------------------------------
@@ -570,8 +557,6 @@ done:
  * Programmer:	Robb Matzke
  *              Tuesday, October  6, 1998
  *
- * Modifications:
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -586,16 +571,16 @@ H5Funmount(hid_t loc_id, const char *name)
     /* Check args */
     if (NULL==(loc=H5G_loc(loc_id)))
 	HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, FAIL, "not a location")
-    if (!name || !*name)
+    if(!name || !*name)
 	HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, FAIL, "no name")
 
     /* Unmount */
-    if (H5F_unmount(loc, name, H5AC_dxpl_id)<0)
+    if (H5F_unmount(loc, name, H5AC_dxpl_id) < 0)
 	HGOTO_ERROR(H5E_FILE, H5E_MOUNT, FAIL, "unable to unmount file")
 
 done:
     FUNC_LEAVE_API(ret_value)
-}
+} /* end H5Funmount() */
 
 
 /*-------------------------------------------------------------------------
@@ -609,8 +594,6 @@ done:
  * Programmer:	Quincey Koziol
  *              Tuesday, July 19, 2005
  *
- * Modifications:
- *
  *-------------------------------------------------------------------------
  */
 static void
@@ -658,8 +641,6 @@ H5F_mount_count_ids_recurse(H5F_t *f, unsigned *nopen_files, unsigned *nopen_obj
  * Programmer:	Quincey Koziol
  *              Tues, July 19, 2005
  *
- * Modifications:
- *
  *-------------------------------------------------------------------------
  */
 herr_t
