@@ -1,4 +1,5 @@
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
+ * Copyright by The HDF Group.                                               *
  * Copyright by the Board of Trustees of the University of Illinois.         *
  * All rights reserved.                                                      *
  *                                                                           *
@@ -8,8 +9,8 @@
  * of the source code distribution tree; Copyright.html can be found at the  *
  * root level of an installed copy of the electronic HDF5 document set and   *
  * is linked from the top-level documents page.  It can also be found at     *
- * http://hdf.ncsa.uiuc.edu/HDF5/doc/Copyright.html.  If you do not have     *
- * access to either file, you may request a copy from hdfhelp@ncsa.uiuc.edu. *
+ * http://hdfgroup.org/HDF5/doc/Copyright.html.  If you do not have          *
+ * access to either file, you may request a copy from help@hdfgroup.org.     *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
 /*
@@ -215,9 +216,9 @@ H5HG_create (H5F_t *f, hid_t dxpl_id, size_t size)
     if (NULL==(heap->chunk = H5FL_BLK_MALLOC (heap_chunk,size)))
 	HGOTO_ERROR (H5E_RESOURCE, H5E_NOSPACE, HADDR_UNDEF, \
                      "memory allocation failed");
-#ifdef H5_USING_PURIFY
-HDmemset(heap->chunk,0,size);
-#endif /* H5_USING_PURIFY */
+#ifdef H5_CLEAR_MEMORY
+HDmemset(heap->chunk, 0, size);
+#endif /* H5_CLEAR_MEMORY */
     heap->nalloc = H5HG_NOBJS (f, size);
     heap->nused = 1; /* account for index 0, which is used for the free object */
     if (NULL==(heap->obj = H5FL_SEQ_MALLOC (H5HG_obj_t,heap->nalloc)))
@@ -448,26 +449,24 @@ H5HG_load (H5F_t *f, hid_t dxpl_id, haddr_t addr, const void UNUSED * udata1,
      * necessary to make room. We remove the right-most entry that has less
      * free space than this heap.
      */
-    if (heap->obj[0].size>0) {
-	if (!f->shared->cwfs) {
-	    f->shared->cwfs = H5MM_malloc (H5HG_NCWFS*sizeof(H5HG_heap_t*));
-	    if (NULL==f->shared->cwfs)
-		HGOTO_ERROR (H5E_RESOURCE, H5E_NOSPACE, NULL, "memory allocation failed");
-	    f->shared->ncwfs = 1;
-	    f->shared->cwfs[0] = heap;
-	} else if (H5HG_NCWFS==f->shared->ncwfs) {
-	    for (i=H5HG_NCWFS-1; i>=0; --i) {
-		if (f->shared->cwfs[i]->obj[0].size < heap->obj[0].size) {
-		    HDmemmove (f->shared->cwfs+1, f->shared->cwfs, i * sizeof(H5HG_heap_t*));
-		    f->shared->cwfs[0] = heap;
-		    break;
-		}
-	    }
-	} else {
-	    HDmemmove (f->shared->cwfs+1, f->shared->cwfs, f->shared->ncwfs*sizeof(H5HG_heap_t*));
-	    f->shared->ncwfs += 1;
-	    f->shared->cwfs[0] = heap;
-	}
+    if (!f->shared->cwfs) {
+        f->shared->cwfs = H5MM_malloc (H5HG_NCWFS*sizeof(H5HG_heap_t*));
+        if (NULL==f->shared->cwfs)
+            HGOTO_ERROR (H5E_RESOURCE, H5E_NOSPACE, NULL, "memory allocation failed");
+        f->shared->ncwfs = 1;
+        f->shared->cwfs[0] = heap;
+    } else if (H5HG_NCWFS==f->shared->ncwfs) {
+        for (i=H5HG_NCWFS-1; i>=0; --i) {
+            if (f->shared->cwfs[i]->obj[0].size < heap->obj[0].size) {
+                HDmemmove (f->shared->cwfs+1, f->shared->cwfs, i * sizeof(H5HG_heap_t*));
+                f->shared->cwfs[0] = heap;
+                break;
+            }
+        }
+    } else {
+        HDmemmove (f->shared->cwfs+1, f->shared->cwfs, f->shared->ncwfs*sizeof(H5HG_heap_t*));
+        f->shared->ncwfs += 1;
+        f->shared->cwfs[0] = heap;
     }
 
     ret_value = heap;
@@ -564,8 +563,11 @@ H5HG_dest (H5F_t *f, H5HG_heap_t *heap)
             break;
         }
     }
-    heap->chunk = H5FL_BLK_FREE(heap_chunk,heap->chunk);
-    heap->obj = H5FL_SEQ_FREE(H5HG_obj_t,heap->obj);
+
+    if (heap->chunk)
+        heap->chunk = H5FL_BLK_FREE(heap_chunk,heap->chunk);
+    if (heap->obj)
+        heap->obj = H5FL_SEQ_FREE(H5HG_obj_t,heap->obj);
     H5FL_FREE (H5HG_heap_t,heap);
 
     FUNC_LEAVE_NOAPI(SUCCEED);
@@ -809,9 +811,9 @@ H5HG_extend (H5F_t *f, H5HG_heap_t *heap, size_t size)
     /* Re-allocate the heap information in memory */
     if (NULL==(new_chunk = H5FL_BLK_REALLOC (heap_chunk, heap->chunk, heap->size+need)))
         HGOTO_ERROR (H5E_RESOURCE, H5E_NOSPACE, FAIL, "new heap allocation failed");
-#ifdef H5_USING_PURIFY
-HDmemset(new_chunk+heap->size,0,need);
-#endif /* H5_USING_PURIFY */
+#ifdef H5_CLEAR_MEMORY
+HDmemset(new_chunk + heap->size, 0, need);
+#endif /* H5_CLEAR_MEMORY */
 
     /* Adjust the size of the heap */
     old_size=heap->size;
