@@ -1,4 +1,5 @@
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
+ * Copyright by The HDF Group.                                               *
  * Copyright by the Board of Trustees of the University of Illinois.         *
  * All rights reserved.                                                      *
  *                                                                           *
@@ -8,8 +9,8 @@
  * of the source code distribution tree; Copyright.html can be found at the  *
  * root level of an installed copy of the electronic HDF5 document set and   *
  * is linked from the top-level documents page.  It can also be found at     *
- * http://hdf.ncsa.uiuc.edu/HDF5/doc/Copyright.html.  If you do not have     *
- * access to either file, you may request a copy from hdfhelp@ncsa.uiuc.edu. *
+ * http://hdfgroup.org/HDF5/doc/Copyright.html.  If you do not have          *
+ * access to either file, you may request a copy from help@hdfgroup.org.     *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
 #define H5O_PACKAGE		/*suppress error about including H5Opkg	  */
@@ -26,7 +27,7 @@
 
 /* PRIVATE PROTOTYPES */
 static herr_t H5O_dtype_encode (H5F_t *f, uint8_t *p, const void *mesg);
-static void *H5O_dtype_decode (H5F_t *f, hid_t dxpl_id, const uint8_t *p, H5O_shared_t *sh);
+static void *H5O_dtype_decode (H5F_t *f, hid_t dxpl_id, const uint8_t *p);
 static void *H5O_dtype_copy (const void *_mesg, void *_dest, unsigned update_flags);
 static size_t H5O_dtype_size (const H5F_t *f, const void *_mesg);
 static herr_t H5O_dtype_reset (void *_mesg);
@@ -38,10 +39,10 @@ static herr_t H5O_dtype_set_share (H5F_t *f, void *_mesg,
 static herr_t H5O_dtype_debug (H5F_t *f, hid_t dxpl_id, const void *_mesg,
 			       FILE * stream, int indent, int fwidth);
 
-/* This message derives from H5O */
-const H5O_class_t H5O_DTYPE[1] = {{
+/* This message derives from H5O message class */
+const H5O_msg_class_t H5O_MSG_DTYPE[1] = {{
     H5O_DTYPE_ID,		/* message id number		*/
-    "data_type",		/* message name for debugging	*/
+    "datatype",			/* message name for debugging	*/
     sizeof(H5T_t),		/* native message size		*/
     H5O_dtype_decode,		/* decode message		*/
     H5O_dtype_encode,		/* encode message		*/
@@ -53,7 +54,7 @@ const H5O_class_t H5O_DTYPE[1] = {{
     NULL,			/* link method			*/
     H5O_dtype_get_share,	/* get share method		*/
     H5O_dtype_set_share,	/* set share method		*/
-    H5O_dtype_debug,		/* debug the message		*/
+    H5O_dtype_debug		/* debug the message		*/
 }};
 
 /* This is the correct version to create all datatypes which don't contain
@@ -65,10 +66,6 @@ const H5O_class_t H5O_DTYPE[1] = {{
  * class objects (array definitely, potentially compound & vlen sequences also) */
 #define H5O_DTYPE_VERSION_UPDATED	2
 
-/* Declare external the free list for H5T_t's */
-H5FL_EXTERN(H5T_t);
-H5FL_EXTERN(H5T_shared_t);
-
 
 /*-------------------------------------------------------------------------
  * Function:	H5O_dtype_decode_helper
@@ -812,8 +809,7 @@ done:
     function using malloc() and is returned to the caller.
 --------------------------------------------------------------------------*/
 static void *
-H5O_dtype_decode(H5F_t *f, hid_t UNUSED dxpl_id, const uint8_t *p,
-		 H5O_shared_t UNUSED *sh)
+H5O_dtype_decode(H5F_t *f, hid_t UNUSED dxpl_id, const uint8_t *p)
 {
     H5T_t		   *dt = NULL;
     void                *ret_value;     /* Return value */
@@ -1092,8 +1088,6 @@ H5O_dtype_free (void *mesg)
  * Programmer:	Robb Matzke
  *		Monday, June  1, 1998
  *
- * Modifications:
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -1101,21 +1095,20 @@ H5O_dtype_get_share(H5F_t UNUSED *f, const void *_mesg,
 		    H5O_shared_t *sh/*out*/)
 {
     const H5T_t	*dt = (const H5T_t *)_mesg;
-    herr_t      ret_value=SUCCEED;       /* Return value */
+    herr_t      ret_value = SUCCEED;       /* Return value */
 
-    FUNC_ENTER_NOAPI_NOINIT(H5O_dtype_get_share);
+    FUNC_ENTER_NOAPI_NOINIT(H5O_dtype_get_share)
 
-    assert (dt);
-    assert (sh);
+    HDassert(dt);
+    HDassert(sh);
 
     if (H5F_addr_defined (dt->ent.header)) {
         /* If the address is defined, this had better be a named datatype */
 	HDassert (H5T_STATE_NAMED==dt->shared->state || H5T_STATE_OPEN==dt->shared->state);
 
-	sh->in_gh = FALSE;
-	sh->u.ent = dt->ent;
+        H5G_ent_copy(&(sh->ent), &(dt->ent), H5_COPY_NULL);
     } else
-	HGOTO_ERROR (H5E_DATATYPE, H5E_CANTINIT, FAIL, "datatype is not sharable");
+	HGOTO_ERROR (H5E_DATATYPE, H5E_CANTINIT, FAIL, "datatype is not sharable")
 
 done:
     FUNC_LEAVE_NOAPI(ret_value);
@@ -1132,33 +1125,27 @@ done:
  * Programmer:	Robb Matzke
  *		Thursday, June	4, 1998
  *
- * Modifications:
- *
- *      Pedro Vicente, <pvn@ncsa.uiuc.edu> 22 Aug 2002
- *      Added `id to name' support.
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
-H5O_dtype_set_share (H5F_t UNUSED *f, void *_mesg/*in,out*/,
+H5O_dtype_set_share(H5F_t UNUSED *f, void *_mesg/*in,out*/,
 		     const H5O_shared_t *sh)
 {
     H5T_t	*dt = (H5T_t *)_mesg;
 
-    FUNC_ENTER_NOAPI_NOINIT_NOFUNC(H5O_dtype_set_share);
+    FUNC_ENTER_NOAPI_NOINIT_NOFUNC(H5O_dtype_set_share)
 
-    assert (dt);
-    assert (sh);
-    assert (!sh->in_gh);
+    HDassert(dt);
+    HDassert(sh);
 
     /* NULL copy here, names not appropriate */
-    H5G_ent_copy(&(dt->ent),&(sh->u.ent),H5G_COPY_NULL);
+    H5G_ent_copy(&(dt->ent), &(sh->ent), H5_COPY_NULL);
 
     /* Note that the datatype is a named datatype */
     dt->shared->state = H5T_STATE_NAMED;
 
-    FUNC_LEAVE_NOAPI(SUCCEED);
-}
+    FUNC_LEAVE_NOAPI(SUCCEED)
+} /* end H5O_dtype_set_share() */
 
 
 /*--------------------------------------------------------------------------
@@ -1476,3 +1463,4 @@ H5O_dtype_debug(H5F_t *f, hid_t dxpl_id, const void *mesg, FILE *stream,
 
     FUNC_LEAVE_NOAPI(SUCCEED);
 }
+
