@@ -1,4 +1,5 @@
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
+ * Copyright by The HDF Group.                                               *
  * Copyright by the Board of Trustees of the University of Illinois.         *
  * All rights reserved.                                                      *
  *                                                                           *
@@ -8,8 +9,8 @@
  * of the source code distribution tree; Copyright.html can be found at the  *
  * root level of an installed copy of the electronic HDF5 document set and   *
  * is linked from the top-level documents page.  It can also be found at     *
- * http://hdf.ncsa.uiuc.edu/HDF5/doc/Copyright.html.  If you do not have     *
- * access to either file, you may request a copy from hdfhelp@ncsa.uiuc.edu. *
+ * http://hdfgroup.org/HDF5/doc/Copyright.html.  If you do not have          *
+ * access to either file, you may request a copy from help@hdfgroup.org.     *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
 #ifndef H5O_PACKAGE
@@ -19,8 +20,11 @@
 #ifndef _H5Opkg_H
 #define _H5Opkg_H
 
-/* Include private header file */
-#include "H5Oprivate.h"          /* Object header functions                */
+/* Get package's private header */
+#include "H5Oprivate.h"		/* Object headers		  	*/
+
+/* Other private headers needed by this file */
+#include "H5ACprivate.h"	/* Metadata cache			*/
 
 /*
  * Align messages on 8-byte boundaries because we would like to copy the
@@ -32,7 +36,7 @@
 
 /* Object header macros */
 #define H5O_NMESGS	32		/*initial number of messages	     */
-#define H5O_NCHUNKS	8		/*initial number of chunks	     */
+#define H5O_NCHUNKS	2		/*initial number of chunks	     */
 
 /* Version of object header structure */
 #define H5O_VERSION		1
@@ -55,11 +59,11 @@
 	       2 +	/*sizeof message data	*/			      \
 	       4)	/*reserved		*/
 
-typedef struct H5O_class_t {
-    int	id;				 /*message type ID on disk   */
+struct H5O_msg_class_t {
+    unsigned	id;				 /*message type ID on disk   */
     const char	*name;				 /*for debugging             */
     size_t	native_size;			 /*size of native message    */
-    void	*(*decode)(H5F_t*, hid_t, const uint8_t*, struct H5O_shared_t*);
+    void	*(*decode)(H5F_t*, hid_t, const uint8_t*);
     herr_t	(*encode)(H5F_t*, uint8_t*, const void*);
     void	*(*copy)(const void*, void*, unsigned);    /*copy native value         */
     size_t	(*raw_size)(const H5F_t*, const void*);/*sizeof raw val	     */
@@ -70,10 +74,10 @@ typedef struct H5O_class_t {
     herr_t	(*get_share)(H5F_t*, const void*, struct H5O_shared_t*);    /* Get shared information */
     herr_t	(*set_share)(H5F_t*, void*, const struct H5O_shared_t*);    /* Set shared information */
     herr_t	(*debug)(H5F_t*, hid_t, const void*, FILE*, int, int);
-} H5O_class_t;
+};
 
 typedef struct H5O_mesg_t {
-    const H5O_class_t	*type;		/*type of message		     */
+    const H5O_msg_class_t	*type;	/*type of message		     */
     hbool_t		dirty;		/*raw out of date wrt native	     */
     uint8_t		flags;		/*message flags			     */
     unsigned		chunkno;	/*chunk number for this mesg	     */
@@ -89,125 +93,128 @@ typedef struct H5O_chunk_t {
     uint8_t	*image;			/*image of file			     */
 } H5O_chunk_t;
 
-typedef struct H5O_t {
+struct H5O_t {
     H5AC_info_t cache_info; /* Information for H5AC cache functions, _must_ be */
                             /* first field in structure */
-    int		version;		/*version number		     */
+    unsigned	version;		/*version number		     */
     int		nlink;			/*link count			     */
-    unsigned	nmesgs;			/*number of messages		     */
-    unsigned	alloc_nmesgs;		/*number of message slots	     */
+    size_t	nmesgs;			/*number of messages		     */
+    size_t	alloc_nmesgs;		/*number of message slots	     */
     H5O_mesg_t	*mesg;			/*array of messages		     */
-    unsigned	nchunks;		/*number of chunks		     */
-    unsigned	alloc_nchunks;		/*chunks allocated		     */
+    size_t	nchunks;		/*number of chunks		     */
+    size_t	alloc_nchunks;		/*chunks allocated		     */
     H5O_chunk_t *chunk;			/*array of chunks		     */
-} H5O_t;
+};
+
+/* H5O inherits cache-like properties from H5AC */
+H5_DLLVAR const H5AC_class_t H5AC_OHDR[1];
+
+/* Header message ID to class mapping */
+H5_DLLVAR const H5O_msg_class_t *const H5O_msg_class_g[19];
+
+/* Declare external the free list for H5O_t's */
+H5FL_EXTERN(H5O_t);
+
+/* Declare external the free list for H5O_mesg_t sequences */
+H5FL_SEQ_EXTERN(H5O_mesg_t);
+
+/* Declare external the free list for H5O_chunk_t sequences */
+H5FL_SEQ_EXTERN(H5O_chunk_t);
+
+/* Declare external the free list for chunk_image blocks */
+H5FL_BLK_EXTERN(chunk_image);
 
 /*
- * Null Message. (0x0000)
+ * Object header messages
  */
-H5_DLLVAR const H5O_class_t H5O_NULL[1];
 
-/*
- * Simple Dataspace Message. (0x0001)
- */
-H5_DLLVAR const H5O_class_t H5O_SDSPACE[1];
+/* Null Message. (0x0000) */
+H5_DLLVAR const H5O_msg_class_t H5O_MSG_NULL[1];
 
-/*
- * Datatype Message. (0x0003)
- */
-H5_DLLVAR const H5O_class_t H5O_DTYPE[1];
+/* Simple Dataspace Message. (0x0001) */
+H5_DLLVAR const H5O_msg_class_t H5O_MSG_SDSPACE[1];
 
-/*
- * Old Fill Value Message. (0x0004)
- */
-H5_DLLVAR const H5O_class_t H5O_FILL[1];
+/* Datatype Message. (0x0003) */
+H5_DLLVAR const H5O_msg_class_t H5O_MSG_DTYPE[1];
 
-/*
- * New Fill Value Message. (0x0005)
- * 
+/* Old Fill Value Message. (0x0004) */
+H5_DLLVAR const H5O_msg_class_t H5O_MSG_FILL[1];
+
+/* New Fill Value Message. (0x0005) */
+/* 
  * The new fill value message is fill value plus
  * space allocation time and fill value writing time and whether fill
  * value is defined.
  */
-H5_DLLVAR const H5O_class_t H5O_FILL_NEW[1];
+H5_DLLVAR const H5O_msg_class_t H5O_MSG_FILL_NEW[1];
 
-/*
- * External File List Message. (0x0007)
- */
-H5_DLLVAR const H5O_class_t H5O_EFL[1];
+/* External File List Message. (0x0007) */
+H5_DLLVAR const H5O_msg_class_t H5O_MSG_EFL[1];
 
-/*
- * Data Layout Message. (0x0008)
- */
-H5_DLLVAR const H5O_class_t H5O_LAYOUT[1];
+/* Data Layout Message. (0x0008) */
+H5_DLLVAR const H5O_msg_class_t H5O_MSG_LAYOUT[1];
 
 #ifdef H5O_ENABLE_BOGUS
+/* "Bogus" Message. (0x0009) */
 /*
- * "Bogus" Message. (0x0009)
+ * Used for debugging - should never be found in valid HDF5 file.
  */
-H5_DLLVAR const H5O_class_t H5O_BOGUS[1];
+H5_DLLVAR const H5O_msg_class_t H5O_MSG_BOGUS[1];
 #endif /* H5O_ENABLE_BOGUS */
 
-/*
- * Filter pipeline message. (0x000b)
- */
-H5_DLLVAR const H5O_class_t H5O_PLINE[1];
+/* Filter pipeline message. (0x000b) */
+H5_DLLVAR const H5O_msg_class_t H5O_MSG_PLINE[1];
 
-/*
- * Attribute Message. (0x000c)
- */
-H5_DLLVAR const H5O_class_t H5O_ATTR[1];
+/* Attribute Message. (0x000c) */
+H5_DLLVAR const H5O_msg_class_t H5O_MSG_ATTR[1];
 
-/*
- * Object name message. (0x000d)
- */
-H5_DLLVAR const H5O_class_t H5O_NAME[1];
+/* Object name message. (0x000d) */
+H5_DLLVAR const H5O_msg_class_t H5O_MSG_NAME[1];
 
+/* Modification Time Message. (0x000e) */
 /*
- * Modification Time Message. (0x000e)
- *
  * The message is just a `time_t'.
  * (See also the "new" modification time message)
  */
-H5_DLLVAR const H5O_class_t H5O_MTIME[1];
+H5_DLLVAR const H5O_msg_class_t H5O_MSG_MTIME[1];
 
-/*
- * Shared Object Message. (0x000f)
- * 
+/* Shared Object Message. (0x000f) */
+/* 
  * This message ID never really appears in an object
  * header.  Instead, bit 2 of the `Flags' field will be set and the ID field
  * will be the ID of the pointed-to message.
  */
-H5_DLLVAR const H5O_class_t H5O_SHARED[1];
+H5_DLLVAR const H5O_msg_class_t H5O_MSG_SHARED[1];
 
-/*
- * Object Header Continuation Message. (0x0010)
- */
-H5_DLLVAR const H5O_class_t H5O_CONT[1];
+/* Object Header Continuation Message. (0x0010) */
+H5_DLLVAR const H5O_msg_class_t H5O_MSG_CONT[1];
 
-/*
- * Symbol Table Message. (0x0011)
- */
-H5_DLLVAR const H5O_class_t H5O_STAB[1];
+/* Symbol Table Message. (0x0011) */
+H5_DLLVAR const H5O_msg_class_t H5O_MSG_STAB[1];
 
-/*
- * New Modification Time Message. (0x0012)
- * 
+/* New Modification Time Message. (0x0012) */
+/* 
  * The message is just a `time_t'.
  */
-H5_DLLVAR const H5O_class_t H5O_MTIME_NEW[1];
+H5_DLLVAR const H5O_msg_class_t H5O_MSG_MTIME_NEW[1];
 
 /* Package-local function prototypes */
-H5_DLL void * H5O_read_real(const H5G_entry_t *ent, const H5O_class_t *type,
+H5_DLL herr_t H5O_init(void);
+H5_DLL herr_t H5O_free_mesg(H5O_mesg_t *mesg);
+H5_DLL void * H5O_read_real(const H5G_entry_t *ent, const H5O_msg_class_t *type,
         int sequence, void *mesg, hid_t dxpl_id);
-H5_DLL void * H5O_free_real(const H5O_class_t *type, void *mesg);
+H5_DLL void * H5O_free_real(const H5O_msg_class_t *type, void *mesg);
 
 /* Shared object operators */
 H5_DLL void * H5O_shared_read(H5F_t *f, hid_t dxpl_id, H5O_shared_t *shared,
-    const H5O_class_t *type, void *mesg);
+    const H5O_msg_class_t *type, void *mesg);
 
 /* Symbol table operators */
-H5_DLL void *H5O_stab_fast(const H5G_cache_t *cache, const struct H5O_class_t *type,
+H5_DLL void *H5O_stab_fast(const H5G_cache_t *cache, const struct H5O_msg_class_t *type,
 			    void *_mesg);
 
+/* Useful metadata cache callbacks */
+H5_DLL herr_t H5O_dest(H5F_t *f, H5O_t *oh);
+
 #endif /* _H5Opkg_H */
+
