@@ -1,4 +1,5 @@
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
+ * Copyright by The HDF Group.                                               *
  * Copyright by the Board of Trustees of the University of Illinois.         *
  * All rights reserved.                                                      *
  *                                                                           *
@@ -8,8 +9,8 @@
  * of the source code distribution tree; Copyright.html can be found at the  *
  * root level of an installed copy of the electronic HDF5 document set and   *
  * is linked from the top-level documents page.  It can also be found at     *
- * http://hdf.ncsa.uiuc.edu/HDF5/doc/Copyright.html.  If you do not have     *
- * access to either file, you may request a copy from hdfhelp@ncsa.uiuc.edu. *
+ * http://hdfgroup.org/HDF5/doc/Copyright.html.  If you do not have          *
+ * access to either file, you may request a copy from help@hdfgroup.org.     *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
 /*
@@ -589,7 +590,7 @@ test_2 (hid_t fapl)
     hid_t	dset=-1;		/*dataset			*/
     hid_t	grp=-1;			/*group to emit diagnostics	*/
     int		fd;			/*external file descriptors	*/
-    hsize_t	i, j;			/*miscellaneous counters	*/
+    size_t	i, j;			/*miscellaneous counters	*/
     hssize_t	n;			/*bytes of I/O			*/
     char	filename[1024];		/*file names			*/
     int		part[25], whole[100];	/*raw data buffers		*/
