@@ -1,4 +1,5 @@
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
+ * Copyright by The HDF Group.                                               *
  * Copyright by the Board of Trustees of the University of Illinois.         *
  * All rights reserved.                                                      *
  *                                                                           *
@@ -8,8 +9,8 @@
  * of the source code distribution tree; Copyright.html can be found at the  *
  * root level of an installed copy of the electronic HDF5 document set and   *
  * is linked from the top-level documents page.  It can also be found at     *
- * http://hdf.ncsa.uiuc.edu/HDF5/doc/Copyright.html.  If you do not have     *
- * access to either file, you may request a copy from hdfhelp@ncsa.uiuc.edu. *
+ * http://hdfgroup.org/HDF5/doc/Copyright.html.  If you do not have          *
+ * access to either file, you may request a copy from help@hdfgroup.org.     *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
 /*
@@ -201,9 +202,11 @@ test_mpio_gb_file(char *filename)
     int ntimes;			/* how many times */
     char  *buf = NULL;
     char  expected;
+    MPI_Offset  size;
     MPI_Offset  mpi_off;
     MPI_Offset  mpi_off_old;
     MPI_Status  mpi_stat;
+    struct stat    stat_buf;
     int is_signed, sizeof_mpi_offset;
 
     nerrs = 0;
@@ -375,6 +378,44 @@ test_mpio_gb_file(char *filename)
 	 */
 	mrc = MPI_Barrier(MPI_COMM_WORLD);
 	VRFY((mrc==MPI_SUCCESS), "Sync before leaving test");
+
+        /* 
+         * Check if MPI_File_get_size works correctly.  Some systems (only SGI Altix 
+         * Propack 4 so far) return wrong file size.  It can be avoided by reconfiguring
+         * with "--disable-mpi-size".  
+         */
+#ifdef H5_HAVE_MPI_GET_SIZE
+	printf("Test if MPI_File_get_size works correctly with %s\n", filename);
+
+	mrc = MPI_File_open(MPI_COMM_WORLD, filename, MPI_MODE_RDONLY, info, &fh);
+	VRFY((mrc==MPI_SUCCESS), "");
+
+        if (MAINPROCESS){			/* only process 0 needs to check it*/
+            mrc = MPI_File_get_size(fh, &size);
+	    VRFY((mrc==MPI_SUCCESS), "");
+
+            mrc=stat(filename, &stat_buf);
+	    VRFY((mrc==0), "");
+           
+            /* Hopefully this casting is safe */
+            if(size != (MPI_Offset)(stat_buf.st_size)) {
+                printf("Warning: MPI_File_get_size doesn't return correct file size.  To avoid using it in the library, reconfigure and rebuild the library with --disable-mpi-size.\n");
+            }
+        }
+
+	/* close file and free the communicator */
+	mrc = MPI_File_close(&fh);
+	VRFY((mrc==MPI_SUCCESS), "MPI_FILE_CLOSE");
+
+	/*
+	 * one more sync to ensure all processes have done reading
+	 * before ending this test.
+	 */
+	mrc = MPI_Barrier(MPI_COMM_WORLD);
+	VRFY((mrc==MPI_SUCCESS), "Sync before leaving test");
+#else
+        printf("Skipped testing MPI_File_get_size because it's disabled\n");
+#endif
     }
 
 finish:
