@@ -1,4 +1,5 @@
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
+ * Copyright by The HDF Group.                                               *
  * Copyright by the Board of Trustees of the University of Illinois.         *
  * All rights reserved.                                                      *
  *                                                                           *
@@ -8,8 +9,8 @@
  * of the source code distribution tree; Copyright.html can be found at the  *
  * root level of an installed copy of the electronic HDF5 document set and   *
  * is linked from the top-level documents page.  It can also be found at     *
- * http://hdf.ncsa.uiuc.edu/HDF5/doc/Copyright.html.  If you do not have     *
- * access to either file, you may request a copy from hdfhelp@ncsa.uiuc.edu. *
+ * http://hdfgroup.org/HDF5/doc/Copyright.html.  If you do not have          *
+ * access to either file, you may request a copy from help@hdfgroup.org.     *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
 #include <stdlib.h>
@@ -17,10 +18,9 @@
 #include <stdio.h>
 #include <ctype.h>
 #include "h5repack.h"
+#include "h5tools_utils.h"
 
-#if 0
-#define PARSE_DEBUG
-#endif
+extern char  *progname;
 
 /*-------------------------------------------------------------------------
  * Function: parse_filter
@@ -94,7 +94,7 @@ obj_list_t* parse_filter(const char *str,
  obj_list=malloc(n*sizeof(obj_list_t));
  if (obj_list==NULL)
  {
-  printf("Could not alloc object list\n");
+  error_msg(progname, "could not allocate object list\n");
   return NULL;
  }
  *n_objs=n;
@@ -117,7 +117,7 @@ obj_list_t* parse_filter(const char *str,
  if (end_obj+1==(int)len)
  {
   if (obj_list) free(obj_list);
-  printf("Input Error: Invalid compression type in <%s>\n",str);
+  error_msg(progname, "input Error: Invalid compression type in <%s>\n",str);
   exit(1);
  }
 
@@ -133,11 +133,13 @@ obj_list_t* parse_filter(const char *str,
    if ( c=='=') {      /*one more parameter */
     scomp[k]='\0';     /*cut space */
 
-     /*SZIP is a special case , it can be
-      SZIP=8,EC
-      SZIP=8,NN
-      */
-
+/*-------------------------------------------------------------------------
+ * H5Z_FILTER_SZIP
+ * szip has the format SZIP=<pixels per block,coding>
+ * pixels per block is a even number in 2-32 and coding method is 'EC' or 'NN'
+ * example SZIP=8,NN
+ *-------------------------------------------------------------------------
+ */
     if (strcmp(scomp,"SZIP")==0)
     {
      l=-1; /* mask index check */
@@ -152,7 +154,7 @@ obj_list_t* parse_filter(const char *str,
       c = str[u];
       if (!isdigit(c) && l==-1){
        if (obj_list) free(obj_list);
-       printf("Input Error: Compression parameter not digit in <%s>\n",str);
+       error_msg(progname, "compression parameter not digit in <%s>\n",str);
        exit(1);
       }
       if (l==-1)
@@ -167,12 +169,12 @@ obj_list_t* parse_filter(const char *str,
         i=len-1; /* end */
         (*n_objs)--; /* we counted an extra ',' */
         if (strcmp(smask,"NN")==0)
-         filt->szip_coding=0;
+         filt->cd_values[j++]=H5_SZIP_NN_OPTION_MASK;
         else if (strcmp(smask,"EC")==0)
-         filt->szip_coding=1;
+         filt->cd_values[j++]=H5_SZIP_EC_OPTION_MASK;
         else
         {
-         printf("Input Error: szip mask must be 'NN' or 'EC' \n");
+         error_msg(progname, "szip mask must be 'NN' or 'EC' \n");
          exit(1);
         }
 
@@ -182,6 +184,13 @@ obj_list_t* parse_filter(const char *str,
      }  /* u */
     } /*if */
 
+
+
+/*-------------------------------------------------------------------------
+ * all other filters
+ *-------------------------------------------------------------------------
+ */
+
     else
     {
      /* here we could have 1 or 2 digits  */
@@ -190,7 +199,7 @@ obj_list_t* parse_filter(const char *str,
       c = str[u];
       if (!isdigit(c)){
        if (obj_list) free(obj_list);
-       printf("Input Error: Compression parameter not digit in <%s>\n",str);
+       error_msg(progname, "compression parameter is not a digit in <%s>\n",str);
        exit(1);
       }
       stype[m]=c;
@@ -225,7 +234,7 @@ obj_list_t* parse_filter(const char *str,
     filt->filtn=H5Z_FILTER_DEFLATE;
     if (no_param) { /*no more parameters, GZIP must have parameter */
      if (obj_list) free(obj_list);
-     printf("Input Error: Missing compression parameter in <%s>\n",str);
+     error_msg(progname, "missing compression parameter in <%s>\n",str);
      exit(1);
     }
    }
@@ -239,7 +248,7 @@ obj_list_t* parse_filter(const char *str,
     filt->filtn=H5Z_FILTER_SZIP;
     if (no_param) { /*no more parameters, SZIP must have parameter */
      if (obj_list) free(obj_list);
-     printf("Input Error: Missing compression parameter in <%s>\n",str);
+     error_msg(progname, "missing compression parameter in <%s>\n",str);
      exit(1);
     }
    }
@@ -253,7 +262,7 @@ obj_list_t* parse_filter(const char *str,
     filt->filtn=H5Z_FILTER_SHUFFLE;
     if (m>0){ /*shuffle does not have parameter */
      if (obj_list) free(obj_list);
-     printf("Input Error: Extra parameter in SHUF <%s>\n",str);
+     error_msg(progname, "extra parameter in SHUF <%s>\n",str);
      exit(1);
     }
    }
@@ -266,13 +275,14 @@ obj_list_t* parse_filter(const char *str,
     filt->filtn=H5Z_FILTER_FLETCHER32;
     if (m>0){ /*shuffle does not have parameter */
      if (obj_list) free(obj_list);
-     printf("Input Error: Extra parameter in FLET <%s>\n",str);
+     error_msg(progname, "extra parameter in FLET <%s>\n",str);
      exit(1);
     }
    }
+
    else {
     if (obj_list) free(obj_list);
-    printf("Input Error: Invalid filter type in <%s>\n",str);
+    error_msg(progname, "invalid filter type in <%s>\n",str);
     exit(1);
    }
   }
@@ -289,7 +299,7 @@ obj_list_t* parse_filter(const char *str,
  case H5Z_FILTER_DEFLATE:
   if (filt->cd_values[0]<0 || filt->cd_values[0]>9 ){
    if (obj_list) free(obj_list);
-   printf("Input Error: Invalid compression parameter in <%s>\n",str);
+   error_msg(progname, "invalid compression parameter in <%s>\n",str);
    exit(1);
   }
   break;
@@ -299,20 +309,21 @@ obj_list_t* parse_filter(const char *str,
   pixels_per_block=filt->cd_values[0];
   if ((pixels_per_block%2)==1) {
    if (obj_list) free(obj_list);
-   printf("Input Error: pixels_per_block is not even in <%s>\n",str);
+   error_msg(progname, "pixels_per_block is not even in <%s>\n",str);
    exit(1);
   }
   if (pixels_per_block>H5_SZIP_MAX_PIXELS_PER_BLOCK) {
    if (obj_list) free(obj_list);
-   printf("Input Error: pixels_per_block is too large in <%s>\n",str);
+   error_msg(progname, "pixels_per_block is too large in <%s>\n",str);
    exit(1);
   }
   if ( (strcmp(smask,"NN")!=0) && (strcmp(smask,"EC")!=0) ) {
    if (obj_list) free(obj_list);
-   printf("Input Error: szip mask must be 'NN' or 'EC' \n");
+   error_msg(progname, "szip mask must be 'NN' or 'EC' \n");
    exit(1);
   }
   break;
+
  };
 
  return obj_list;
@@ -342,7 +353,7 @@ const char* get_sfilter(H5Z_filter_t filtn)
  else if (filtn==H5Z_FILTER_FLETCHER32)
   return "FLETCHER32";
  else {
-  printf("Input error in filter type\n");
+  error_msg(progname, "input error in filter type\n");
   exit(1);
  }
  return NULL;
@@ -411,7 +422,7 @@ obj_list_t* parse_layout(const char *str,
  obj_list=malloc(n*sizeof(obj_list_t));
  if (obj_list==NULL)
  {
-  printf("Could not alloc object list\n");
+  error_msg(progname, "could not allocate object list\n");
   return NULL;
  }
  *n_objs=n;
@@ -435,7 +446,7 @@ obj_list_t* parse_layout(const char *str,
  if (end_obj+1==(int)len)
  {
   if (obj_list) free(obj_list);
-  printf("Parse layout error: No characters after : in <%s>\n",str);
+  error_msg(progname, "in parse layout, no characters after : in <%s>\n",str);
   exit(1);
  }
 
@@ -452,7 +463,7 @@ obj_list_t* parse_layout(const char *str,
    else if (strcmp(slayout,"CHUNK")==0)
     pack->layout=H5D_CHUNKED;
    else {
-    printf("Parse layout error: Not a valid layout in <%s>\n",str);
+    error_msg(progname, "in parse layout, not a valid layout in <%s>\n",str);
     exit(1);
    }
   }
@@ -476,7 +487,7 @@ obj_list_t* parse_layout(const char *str,
    if (j>(int)len)
    {
     if (obj_list) free(obj_list);
-    printf("Parse layout error: <%s> Chunk dimensions missing\n",str);
+    error_msg(progname, "in parse layout,  <%s> Chunk dimensions missing\n",str);
     exit(1);
    }
 
@@ -490,7 +501,7 @@ obj_list_t* parse_layout(const char *str,
      && c!='N' && c!='O' && c!='N' && c!='E'
      ){
      if (obj_list) free(obj_list);
-     printf("Parse layout error: <%s> Not a valid character in <%s>\n",
+     error_msg(progname, "in parse layout, <%s> Not a valid character in <%s>\n",
       sdim,str);
      exit(1);
     }
@@ -503,7 +514,7 @@ obj_list_t* parse_layout(const char *str,
       pack->chunk.chunk_lengths[c_index]=atoi(sdim);
       if (pack->chunk.chunk_lengths[c_index]==0) {
        if (obj_list) free(obj_list);
-       printf("Parse layout error: <%s> Conversion to number in <%s>\n",
+       error_msg(progname, "in parse layout, <%s> conversion to number in <%s>\n",
         sdim,str);
        exit(1);
       }
@@ -521,7 +532,7 @@ obj_list_t* parse_layout(const char *str,
        pack->chunk.chunk_lengths[c_index]=atoi(sdim);
        if (pack->chunk.chunk_lengths[c_index]==0){
         if (obj_list) free(obj_list);
-        printf("Parse layout error: <%s> Conversion to number in <%s>\n",
+        error_msg(progname, "in parse layout, <%s> conversion to number in <%s>\n",
          sdim,str);
         exit(1);
        }
@@ -538,8 +549,6 @@ obj_list_t* parse_layout(const char *str,
  return obj_list;
 }
 
-
-
 /*-------------------------------------------------------------------------
  * Function: parse_number
  *
